from .account_budget_proposal_service import (
    AccountBudgetProposalOperation as AccountBudgetProposalOperation,
    MutateAccountBudgetProposalRequest as MutateAccountBudgetProposalRequest,
    MutateAccountBudgetProposalResponse as MutateAccountBudgetProposalResponse,
    MutateAccountBudgetProposalResult as MutateAccountBudgetProposalResult,
)
from .account_link_service import (
    AccountLinkOperation as AccountLinkOperation,
    CreateAccountLinkRequest as CreateAccountLinkRequest,
    CreateAccountLinkResponse as CreateAccountLinkResponse,
    MutateAccountLinkRequest as MutateAccountLinkRequest,
    MutateAccountLinkResponse as MutateAccountLinkResponse,
    MutateAccountLinkResult as MutateAccountLinkResult,
)
from .ad_group_ad_label_service import (
    AdGroupAdLabelOperation as AdGroupAdLabelOperation,
    MutateAdGroupAdLabelResult as MutateAdGroupAdLabelResult,
    MutateAdGroupAdLabelsRequest as MutateAdGroupAdLabelsRequest,
    MutateAdGroupAdLabelsResponse as MutateAdGroupAdLabelsResponse,
)
from .ad_group_ad_service import (
    AdGroupAdOperation as AdGroupAdOperation,
    AssetsWithFieldType as AssetsWithFieldType,
    MutateAdGroupAdResult as MutateAdGroupAdResult,
    MutateAdGroupAdsRequest as MutateAdGroupAdsRequest,
    MutateAdGroupAdsResponse as MutateAdGroupAdsResponse,
    RemoveAutomaticallyCreatedAssetsRequest as RemoveAutomaticallyCreatedAssetsRequest,
)
from .ad_group_asset_service import (
    AdGroupAssetOperation as AdGroupAssetOperation,
    MutateAdGroupAssetResult as MutateAdGroupAssetResult,
    MutateAdGroupAssetsRequest as MutateAdGroupAssetsRequest,
    MutateAdGroupAssetsResponse as MutateAdGroupAssetsResponse,
)
from .ad_group_asset_set_service import (
    AdGroupAssetSetOperation as AdGroupAssetSetOperation,
    MutateAdGroupAssetSetResult as MutateAdGroupAssetSetResult,
    MutateAdGroupAssetSetsRequest as MutateAdGroupAssetSetsRequest,
    MutateAdGroupAssetSetsResponse as MutateAdGroupAssetSetsResponse,
)
from .ad_group_bid_modifier_service import (
    AdGroupBidModifierOperation as AdGroupBidModifierOperation,
    MutateAdGroupBidModifierResult as MutateAdGroupBidModifierResult,
    MutateAdGroupBidModifiersRequest as MutateAdGroupBidModifiersRequest,
    MutateAdGroupBidModifiersResponse as MutateAdGroupBidModifiersResponse,
)
from .ad_group_criterion_customizer_service import (
    AdGroupCriterionCustomizerOperation as AdGroupCriterionCustomizerOperation,
    MutateAdGroupCriterionCustomizerResult as MutateAdGroupCriterionCustomizerResult,
    MutateAdGroupCriterionCustomizersRequest as MutateAdGroupCriterionCustomizersRequest,
    MutateAdGroupCriterionCustomizersResponse as MutateAdGroupCriterionCustomizersResponse,
)
from .ad_group_criterion_label_service import (
    AdGroupCriterionLabelOperation as AdGroupCriterionLabelOperation,
    MutateAdGroupCriterionLabelResult as MutateAdGroupCriterionLabelResult,
    MutateAdGroupCriterionLabelsRequest as MutateAdGroupCriterionLabelsRequest,
    MutateAdGroupCriterionLabelsResponse as MutateAdGroupCriterionLabelsResponse,
)
from .ad_group_criterion_service import (
    AdGroupCriterionOperation as AdGroupCriterionOperation,
    MutateAdGroupCriteriaRequest as MutateAdGroupCriteriaRequest,
    MutateAdGroupCriteriaResponse as MutateAdGroupCriteriaResponse,
    MutateAdGroupCriterionResult as MutateAdGroupCriterionResult,
)
from .ad_group_customizer_service import (
    AdGroupCustomizerOperation as AdGroupCustomizerOperation,
    MutateAdGroupCustomizerResult as MutateAdGroupCustomizerResult,
    MutateAdGroupCustomizersRequest as MutateAdGroupCustomizersRequest,
    MutateAdGroupCustomizersResponse as MutateAdGroupCustomizersResponse,
)
from .ad_group_label_service import (
    AdGroupLabelOperation as AdGroupLabelOperation,
    MutateAdGroupLabelResult as MutateAdGroupLabelResult,
    MutateAdGroupLabelsRequest as MutateAdGroupLabelsRequest,
    MutateAdGroupLabelsResponse as MutateAdGroupLabelsResponse,
)
from .ad_group_service import (
    AdGroupOperation as AdGroupOperation,
    MutateAdGroupResult as MutateAdGroupResult,
    MutateAdGroupsRequest as MutateAdGroupsRequest,
    MutateAdGroupsResponse as MutateAdGroupsResponse,
)
from .ad_parameter_service import (
    AdParameterOperation as AdParameterOperation,
    MutateAdParameterResult as MutateAdParameterResult,
    MutateAdParametersRequest as MutateAdParametersRequest,
    MutateAdParametersResponse as MutateAdParametersResponse,
)
from .ad_service import (
    AdOperation as AdOperation,
    MutateAdResult as MutateAdResult,
    MutateAdsRequest as MutateAdsRequest,
    MutateAdsResponse as MutateAdsResponse,
)
from .asset_group_asset_service import (
    AssetGroupAssetOperation as AssetGroupAssetOperation,
    MutateAssetGroupAssetResult as MutateAssetGroupAssetResult,
    MutateAssetGroupAssetsRequest as MutateAssetGroupAssetsRequest,
    MutateAssetGroupAssetsResponse as MutateAssetGroupAssetsResponse,
)
from .asset_group_listing_group_filter_service import (
    AssetGroupListingGroupFilterOperation as AssetGroupListingGroupFilterOperation,
    MutateAssetGroupListingGroupFilterResult as MutateAssetGroupListingGroupFilterResult,
    MutateAssetGroupListingGroupFiltersRequest as MutateAssetGroupListingGroupFiltersRequest,
    MutateAssetGroupListingGroupFiltersResponse as MutateAssetGroupListingGroupFiltersResponse,
)
from .asset_group_service import (
    AssetGroupOperation as AssetGroupOperation,
    MutateAssetGroupResult as MutateAssetGroupResult,
    MutateAssetGroupsRequest as MutateAssetGroupsRequest,
    MutateAssetGroupsResponse as MutateAssetGroupsResponse,
)
from .asset_group_signal_service import (
    AssetGroupSignalOperation as AssetGroupSignalOperation,
    MutateAssetGroupSignalResult as MutateAssetGroupSignalResult,
    MutateAssetGroupSignalsRequest as MutateAssetGroupSignalsRequest,
    MutateAssetGroupSignalsResponse as MutateAssetGroupSignalsResponse,
)
from .asset_service import (
    AssetOperation as AssetOperation,
    MutateAssetResult as MutateAssetResult,
    MutateAssetsRequest as MutateAssetsRequest,
    MutateAssetsResponse as MutateAssetsResponse,
)
from .asset_set_asset_service import (
    AssetSetAssetOperation as AssetSetAssetOperation,
    MutateAssetSetAssetResult as MutateAssetSetAssetResult,
    MutateAssetSetAssetsRequest as MutateAssetSetAssetsRequest,
    MutateAssetSetAssetsResponse as MutateAssetSetAssetsResponse,
)
from .asset_set_service import (
    AssetSetOperation as AssetSetOperation,
    MutateAssetSetResult as MutateAssetSetResult,
    MutateAssetSetsRequest as MutateAssetSetsRequest,
    MutateAssetSetsResponse as MutateAssetSetsResponse,
)
from .audience_insights_service import (
    AudienceCompositionAttribute as AudienceCompositionAttribute,
    AudienceCompositionAttributeCluster as AudienceCompositionAttributeCluster,
    AudienceCompositionMetrics as AudienceCompositionMetrics,
    AudienceCompositionSection as AudienceCompositionSection,
    AudienceOverlapItem as AudienceOverlapItem,
    BasicInsightsAudience as BasicInsightsAudience,
    DimensionOverlapResult as DimensionOverlapResult,
    GenerateAudienceCompositionInsightsRequest as GenerateAudienceCompositionInsightsRequest,
    GenerateAudienceCompositionInsightsResponse as GenerateAudienceCompositionInsightsResponse,
    GenerateAudienceOverlapInsightsRequest as GenerateAudienceOverlapInsightsRequest,
    GenerateAudienceOverlapInsightsResponse as GenerateAudienceOverlapInsightsResponse,
    GenerateInsightsFinderReportRequest as GenerateInsightsFinderReportRequest,
    GenerateInsightsFinderReportResponse as GenerateInsightsFinderReportResponse,
    GenerateSuggestedTargetingInsightsRequest as GenerateSuggestedTargetingInsightsRequest,
    GenerateSuggestedTargetingInsightsResponse as GenerateSuggestedTargetingInsightsResponse,
    GenerateTargetingSuggestionMetricsRequest as GenerateTargetingSuggestionMetricsRequest,
    GenerateTargetingSuggestionMetricsResponse as GenerateTargetingSuggestionMetricsResponse,
    InsightsAudience as InsightsAudience,
    InsightsAudienceAttributeGroup as InsightsAudienceAttributeGroup,
    InsightsAudienceDefinition as InsightsAudienceDefinition,
    InsightsAudienceDescription as InsightsAudienceDescription,
    ListAudienceInsightsAttributesRequest as ListAudienceInsightsAttributesRequest,
    ListAudienceInsightsAttributesResponse as ListAudienceInsightsAttributesResponse,
    ListInsightsEligibleDatesRequest as ListInsightsEligibleDatesRequest,
    ListInsightsEligibleDatesResponse as ListInsightsEligibleDatesResponse,
    TargetingSuggestionMetrics as TargetingSuggestionMetrics,
)
from .audience_service import (
    AudienceOperation as AudienceOperation,
    MutateAudienceResult as MutateAudienceResult,
    MutateAudiencesRequest as MutateAudiencesRequest,
    MutateAudiencesResponse as MutateAudiencesResponse,
)
from .batch_job_service import (
    AddBatchJobOperationsRequest as AddBatchJobOperationsRequest,
    AddBatchJobOperationsResponse as AddBatchJobOperationsResponse,
    BatchJobOperation as BatchJobOperation,
    BatchJobResult as BatchJobResult,
    ListBatchJobResultsRequest as ListBatchJobResultsRequest,
    ListBatchJobResultsResponse as ListBatchJobResultsResponse,
    MutateBatchJobRequest as MutateBatchJobRequest,
    MutateBatchJobResponse as MutateBatchJobResponse,
    MutateBatchJobResult as MutateBatchJobResult,
    RunBatchJobRequest as RunBatchJobRequest,
)
from .bidding_data_exclusion_service import (
    BiddingDataExclusionOperation as BiddingDataExclusionOperation,
    MutateBiddingDataExclusionsRequest as MutateBiddingDataExclusionsRequest,
    MutateBiddingDataExclusionsResponse as MutateBiddingDataExclusionsResponse,
    MutateBiddingDataExclusionsResult as MutateBiddingDataExclusionsResult,
)
from .bidding_seasonality_adjustment_service import (
    BiddingSeasonalityAdjustmentOperation as BiddingSeasonalityAdjustmentOperation,
    MutateBiddingSeasonalityAdjustmentsRequest as MutateBiddingSeasonalityAdjustmentsRequest,
    MutateBiddingSeasonalityAdjustmentsResponse as MutateBiddingSeasonalityAdjustmentsResponse,
    MutateBiddingSeasonalityAdjustmentsResult as MutateBiddingSeasonalityAdjustmentsResult,
)
from .bidding_strategy_service import (
    BiddingStrategyOperation as BiddingStrategyOperation,
    MutateBiddingStrategiesRequest as MutateBiddingStrategiesRequest,
    MutateBiddingStrategiesResponse as MutateBiddingStrategiesResponse,
    MutateBiddingStrategyResult as MutateBiddingStrategyResult,
)
from .billing_setup_service import (
    BillingSetupOperation as BillingSetupOperation,
    MutateBillingSetupRequest as MutateBillingSetupRequest,
    MutateBillingSetupResponse as MutateBillingSetupResponse,
    MutateBillingSetupResult as MutateBillingSetupResult,
)
from .brand_suggestion_service import (
    BrandSuggestion as BrandSuggestion,
    SuggestBrandsRequest as SuggestBrandsRequest,
    SuggestBrandsResponse as SuggestBrandsResponse,
)
from .campaign_asset_service import (
    CampaignAssetOperation as CampaignAssetOperation,
    MutateCampaignAssetResult as MutateCampaignAssetResult,
    MutateCampaignAssetsRequest as MutateCampaignAssetsRequest,
    MutateCampaignAssetsResponse as MutateCampaignAssetsResponse,
)
from .campaign_asset_set_service import (
    CampaignAssetSetOperation as CampaignAssetSetOperation,
    MutateCampaignAssetSetResult as MutateCampaignAssetSetResult,
    MutateCampaignAssetSetsRequest as MutateCampaignAssetSetsRequest,
    MutateCampaignAssetSetsResponse as MutateCampaignAssetSetsResponse,
)
from .campaign_bid_modifier_service import (
    CampaignBidModifierOperation as CampaignBidModifierOperation,
    MutateCampaignBidModifierResult as MutateCampaignBidModifierResult,
    MutateCampaignBidModifiersRequest as MutateCampaignBidModifiersRequest,
    MutateCampaignBidModifiersResponse as MutateCampaignBidModifiersResponse,
)
from .campaign_budget_service import (
    CampaignBudgetOperation as CampaignBudgetOperation,
    MutateCampaignBudgetResult as MutateCampaignBudgetResult,
    MutateCampaignBudgetsRequest as MutateCampaignBudgetsRequest,
    MutateCampaignBudgetsResponse as MutateCampaignBudgetsResponse,
)
from .campaign_conversion_goal_service import (
    CampaignConversionGoalOperation as CampaignConversionGoalOperation,
    MutateCampaignConversionGoalResult as MutateCampaignConversionGoalResult,
    MutateCampaignConversionGoalsRequest as MutateCampaignConversionGoalsRequest,
    MutateCampaignConversionGoalsResponse as MutateCampaignConversionGoalsResponse,
)
from .campaign_criterion_service import (
    CampaignCriterionOperation as CampaignCriterionOperation,
    MutateCampaignCriteriaRequest as MutateCampaignCriteriaRequest,
    MutateCampaignCriteriaResponse as MutateCampaignCriteriaResponse,
    MutateCampaignCriterionResult as MutateCampaignCriterionResult,
)
from .campaign_customizer_service import (
    CampaignCustomizerOperation as CampaignCustomizerOperation,
    MutateCampaignCustomizerResult as MutateCampaignCustomizerResult,
    MutateCampaignCustomizersRequest as MutateCampaignCustomizersRequest,
    MutateCampaignCustomizersResponse as MutateCampaignCustomizersResponse,
)
from .campaign_draft_service import (
    CampaignDraftOperation as CampaignDraftOperation,
    ListCampaignDraftAsyncErrorsRequest as ListCampaignDraftAsyncErrorsRequest,
    ListCampaignDraftAsyncErrorsResponse as ListCampaignDraftAsyncErrorsResponse,
    MutateCampaignDraftResult as MutateCampaignDraftResult,
    MutateCampaignDraftsRequest as MutateCampaignDraftsRequest,
    MutateCampaignDraftsResponse as MutateCampaignDraftsResponse,
    PromoteCampaignDraftRequest as PromoteCampaignDraftRequest,
)
from .campaign_group_service import (
    CampaignGroupOperation as CampaignGroupOperation,
    MutateCampaignGroupResult as MutateCampaignGroupResult,
    MutateCampaignGroupsRequest as MutateCampaignGroupsRequest,
    MutateCampaignGroupsResponse as MutateCampaignGroupsResponse,
)
from .campaign_label_service import (
    CampaignLabelOperation as CampaignLabelOperation,
    MutateCampaignLabelResult as MutateCampaignLabelResult,
    MutateCampaignLabelsRequest as MutateCampaignLabelsRequest,
    MutateCampaignLabelsResponse as MutateCampaignLabelsResponse,
)
from .campaign_lifecycle_goal_service import (
    CampaignLifecycleGoalOperation as CampaignLifecycleGoalOperation,
    ConfigureCampaignLifecycleGoalsRequest as ConfigureCampaignLifecycleGoalsRequest,
    ConfigureCampaignLifecycleGoalsResponse as ConfigureCampaignLifecycleGoalsResponse,
    ConfigureCampaignLifecycleGoalsResult as ConfigureCampaignLifecycleGoalsResult,
)
from .campaign_service import (
    BrandCampaignAssets as BrandCampaignAssets,
    CampaignOperation as CampaignOperation,
    EnablementResult as EnablementResult,
    EnableOperation as EnableOperation,
    EnablePMaxBrandGuidelinesRequest as EnablePMaxBrandGuidelinesRequest,
    EnablePMaxBrandGuidelinesResponse as EnablePMaxBrandGuidelinesResponse,
    MutateCampaignResult as MutateCampaignResult,
    MutateCampaignsRequest as MutateCampaignsRequest,
    MutateCampaignsResponse as MutateCampaignsResponse,
)
from .campaign_shared_set_service import (
    CampaignSharedSetOperation as CampaignSharedSetOperation,
    MutateCampaignSharedSetResult as MutateCampaignSharedSetResult,
    MutateCampaignSharedSetsRequest as MutateCampaignSharedSetsRequest,
    MutateCampaignSharedSetsResponse as MutateCampaignSharedSetsResponse,
)
from .content_creator_insights_service import (
    GenerateCreatorInsightsRequest as GenerateCreatorInsightsRequest,
    GenerateCreatorInsightsResponse as GenerateCreatorInsightsResponse,
    GenerateTrendingInsightsRequest as GenerateTrendingInsightsRequest,
    GenerateTrendingInsightsResponse as GenerateTrendingInsightsResponse,
    SearchAudience as SearchAudience,
    SearchTopics as SearchTopics,
    TrendInsight as TrendInsight,
    TrendInsightMetrics as TrendInsightMetrics,
    YouTubeChannelInsights as YouTubeChannelInsights,
    YouTubeCreatorInsights as YouTubeCreatorInsights,
    YouTubeMetrics as YouTubeMetrics,
)
from .conversion_action_service import (
    ConversionActionOperation as ConversionActionOperation,
    MutateConversionActionResult as MutateConversionActionResult,
    MutateConversionActionsRequest as MutateConversionActionsRequest,
    MutateConversionActionsResponse as MutateConversionActionsResponse,
)
from .conversion_adjustment_upload_service import (
    ConversionAdjustment as ConversionAdjustment,
    ConversionAdjustmentResult as ConversionAdjustmentResult,
    GclidDateTimePair as GclidDateTimePair,
    RestatementValue as RestatementValue,
    UploadConversionAdjustmentsRequest as UploadConversionAdjustmentsRequest,
    UploadConversionAdjustmentsResponse as UploadConversionAdjustmentsResponse,
)
from .conversion_custom_variable_service import (
    ConversionCustomVariableOperation as ConversionCustomVariableOperation,
    MutateConversionCustomVariableResult as MutateConversionCustomVariableResult,
    MutateConversionCustomVariablesRequest as MutateConversionCustomVariablesRequest,
    MutateConversionCustomVariablesResponse as MutateConversionCustomVariablesResponse,
)
from .conversion_goal_campaign_config_service import (
    ConversionGoalCampaignConfigOperation as ConversionGoalCampaignConfigOperation,
    MutateConversionGoalCampaignConfigResult as MutateConversionGoalCampaignConfigResult,
    MutateConversionGoalCampaignConfigsRequest as MutateConversionGoalCampaignConfigsRequest,
    MutateConversionGoalCampaignConfigsResponse as MutateConversionGoalCampaignConfigsResponse,
)
from .conversion_upload_service import (
    CallConversion as CallConversion,
    CallConversionResult as CallConversionResult,
    CartData as CartData,
    ClickConversion as ClickConversion,
    ClickConversionResult as ClickConversionResult,
    CustomVariable as CustomVariable,
    ExternalAttributionData as ExternalAttributionData,
    SessionAttributeKeyValuePair as SessionAttributeKeyValuePair,
    SessionAttributesKeyValuePairs as SessionAttributesKeyValuePairs,
    UploadCallConversionsRequest as UploadCallConversionsRequest,
    UploadCallConversionsResponse as UploadCallConversionsResponse,
    UploadClickConversionsRequest as UploadClickConversionsRequest,
    UploadClickConversionsResponse as UploadClickConversionsResponse,
)
from .conversion_value_rule_service import (
    ConversionValueRuleOperation as ConversionValueRuleOperation,
    MutateConversionValueRuleResult as MutateConversionValueRuleResult,
    MutateConversionValueRulesRequest as MutateConversionValueRulesRequest,
    MutateConversionValueRulesResponse as MutateConversionValueRulesResponse,
)
from .conversion_value_rule_set_service import (
    ConversionValueRuleSetOperation as ConversionValueRuleSetOperation,
    MutateConversionValueRuleSetResult as MutateConversionValueRuleSetResult,
    MutateConversionValueRuleSetsRequest as MutateConversionValueRuleSetsRequest,
    MutateConversionValueRuleSetsResponse as MutateConversionValueRuleSetsResponse,
)
from .custom_audience_service import (
    CustomAudienceOperation as CustomAudienceOperation,
    MutateCustomAudienceResult as MutateCustomAudienceResult,
    MutateCustomAudiencesRequest as MutateCustomAudiencesRequest,
    MutateCustomAudiencesResponse as MutateCustomAudiencesResponse,
)
from .custom_conversion_goal_service import (
    CustomConversionGoalOperation as CustomConversionGoalOperation,
    MutateCustomConversionGoalResult as MutateCustomConversionGoalResult,
    MutateCustomConversionGoalsRequest as MutateCustomConversionGoalsRequest,
    MutateCustomConversionGoalsResponse as MutateCustomConversionGoalsResponse,
)
from .custom_interest_service import (
    CustomInterestOperation as CustomInterestOperation,
    MutateCustomInterestResult as MutateCustomInterestResult,
    MutateCustomInterestsRequest as MutateCustomInterestsRequest,
    MutateCustomInterestsResponse as MutateCustomInterestsResponse,
)
from .customer_asset_service import (
    CustomerAssetOperation as CustomerAssetOperation,
    MutateCustomerAssetResult as MutateCustomerAssetResult,
    MutateCustomerAssetsRequest as MutateCustomerAssetsRequest,
    MutateCustomerAssetsResponse as MutateCustomerAssetsResponse,
)
from .customer_asset_set_service import (
    CustomerAssetSetOperation as CustomerAssetSetOperation,
    MutateCustomerAssetSetResult as MutateCustomerAssetSetResult,
    MutateCustomerAssetSetsRequest as MutateCustomerAssetSetsRequest,
    MutateCustomerAssetSetsResponse as MutateCustomerAssetSetsResponse,
)
from .customer_client_link_service import (
    CustomerClientLinkOperation as CustomerClientLinkOperation,
    MutateCustomerClientLinkRequest as MutateCustomerClientLinkRequest,
    MutateCustomerClientLinkResponse as MutateCustomerClientLinkResponse,
    MutateCustomerClientLinkResult as MutateCustomerClientLinkResult,
)
from .customer_conversion_goal_service import (
    CustomerConversionGoalOperation as CustomerConversionGoalOperation,
    MutateCustomerConversionGoalResult as MutateCustomerConversionGoalResult,
    MutateCustomerConversionGoalsRequest as MutateCustomerConversionGoalsRequest,
    MutateCustomerConversionGoalsResponse as MutateCustomerConversionGoalsResponse,
)
from .customer_customizer_service import (
    CustomerCustomizerOperation as CustomerCustomizerOperation,
    MutateCustomerCustomizerResult as MutateCustomerCustomizerResult,
    MutateCustomerCustomizersRequest as MutateCustomerCustomizersRequest,
    MutateCustomerCustomizersResponse as MutateCustomerCustomizersResponse,
)
from .customer_label_service import (
    CustomerLabelOperation as CustomerLabelOperation,
    MutateCustomerLabelResult as MutateCustomerLabelResult,
    MutateCustomerLabelsRequest as MutateCustomerLabelsRequest,
    MutateCustomerLabelsResponse as MutateCustomerLabelsResponse,
)
from .customer_lifecycle_goal_service import (
    ConfigureCustomerLifecycleGoalsRequest as ConfigureCustomerLifecycleGoalsRequest,
    ConfigureCustomerLifecycleGoalsResponse as ConfigureCustomerLifecycleGoalsResponse,
    ConfigureCustomerLifecycleGoalsResult as ConfigureCustomerLifecycleGoalsResult,
    CustomerLifecycleGoalOperation as CustomerLifecycleGoalOperation,
)
from .customer_manager_link_service import (
    CustomerManagerLinkOperation as CustomerManagerLinkOperation,
    MoveManagerLinkRequest as MoveManagerLinkRequest,
    MoveManagerLinkResponse as MoveManagerLinkResponse,
    MutateCustomerManagerLinkRequest as MutateCustomerManagerLinkRequest,
    MutateCustomerManagerLinkResponse as MutateCustomerManagerLinkResponse,
    MutateCustomerManagerLinkResult as MutateCustomerManagerLinkResult,
)
from .customer_negative_criterion_service import (
    CustomerNegativeCriterionOperation as CustomerNegativeCriterionOperation,
    MutateCustomerNegativeCriteriaRequest as MutateCustomerNegativeCriteriaRequest,
    MutateCustomerNegativeCriteriaResponse as MutateCustomerNegativeCriteriaResponse,
    MutateCustomerNegativeCriteriaResult as MutateCustomerNegativeCriteriaResult,
)
from .customer_service import (
    CreateCustomerClientRequest as CreateCustomerClientRequest,
    CreateCustomerClientResponse as CreateCustomerClientResponse,
    CustomerOperation as CustomerOperation,
    ListAccessibleCustomersRequest as ListAccessibleCustomersRequest,
    ListAccessibleCustomersResponse as ListAccessibleCustomersResponse,
    MutateCustomerRequest as MutateCustomerRequest,
    MutateCustomerResponse as MutateCustomerResponse,
    MutateCustomerResult as MutateCustomerResult,
)
from .customer_sk_ad_network_conversion_value_schema_service import (
    CustomerSkAdNetworkConversionValueSchemaOperation as CustomerSkAdNetworkConversionValueSchemaOperation,
    MutateCustomerSkAdNetworkConversionValueSchemaRequest as MutateCustomerSkAdNetworkConversionValueSchemaRequest,
    MutateCustomerSkAdNetworkConversionValueSchemaResponse as MutateCustomerSkAdNetworkConversionValueSchemaResponse,
    MutateCustomerSkAdNetworkConversionValueSchemaResult as MutateCustomerSkAdNetworkConversionValueSchemaResult,
)
from .customer_user_access_invitation_service import (
    CustomerUserAccessInvitationOperation as CustomerUserAccessInvitationOperation,
    MutateCustomerUserAccessInvitationRequest as MutateCustomerUserAccessInvitationRequest,
    MutateCustomerUserAccessInvitationResponse as MutateCustomerUserAccessInvitationResponse,
    MutateCustomerUserAccessInvitationResult as MutateCustomerUserAccessInvitationResult,
)
from .customer_user_access_service import (
    CustomerUserAccessOperation as CustomerUserAccessOperation,
    MutateCustomerUserAccessRequest as MutateCustomerUserAccessRequest,
    MutateCustomerUserAccessResponse as MutateCustomerUserAccessResponse,
    MutateCustomerUserAccessResult as MutateCustomerUserAccessResult,
)
from .customizer_attribute_service import (
    CustomizerAttributeOperation as CustomizerAttributeOperation,
    MutateCustomizerAttributeResult as MutateCustomizerAttributeResult,
    MutateCustomizerAttributesRequest as MutateCustomizerAttributesRequest,
    MutateCustomizerAttributesResponse as MutateCustomizerAttributesResponse,
)
from .data_link_service import (
    CreateDataLinkRequest as CreateDataLinkRequest,
    CreateDataLinkResponse as CreateDataLinkResponse,
    RemoveDataLinkRequest as RemoveDataLinkRequest,
    RemoveDataLinkResponse as RemoveDataLinkResponse,
    UpdateDataLinkRequest as UpdateDataLinkRequest,
    UpdateDataLinkResponse as UpdateDataLinkResponse,
)
from .experiment_arm_service import (
    ExperimentArmOperation as ExperimentArmOperation,
    MutateExperimentArmResult as MutateExperimentArmResult,
    MutateExperimentArmsRequest as MutateExperimentArmsRequest,
    MutateExperimentArmsResponse as MutateExperimentArmsResponse,
)
from .experiment_service import (
    CampaignBudgetMapping as CampaignBudgetMapping,
    EndExperimentRequest as EndExperimentRequest,
    ExperimentOperation as ExperimentOperation,
    GraduateExperimentRequest as GraduateExperimentRequest,
    ListExperimentAsyncErrorsRequest as ListExperimentAsyncErrorsRequest,
    ListExperimentAsyncErrorsResponse as ListExperimentAsyncErrorsResponse,
    MutateExperimentResult as MutateExperimentResult,
    MutateExperimentsRequest as MutateExperimentsRequest,
    MutateExperimentsResponse as MutateExperimentsResponse,
    PromoteExperimentMetadata as PromoteExperimentMetadata,
    PromoteExperimentRequest as PromoteExperimentRequest,
    ScheduleExperimentMetadata as ScheduleExperimentMetadata,
    ScheduleExperimentRequest as ScheduleExperimentRequest,
)
from .geo_target_constant_service import (
    GeoTargetConstantSuggestion as GeoTargetConstantSuggestion,
    SuggestGeoTargetConstantsRequest as SuggestGeoTargetConstantsRequest,
    SuggestGeoTargetConstantsResponse as SuggestGeoTargetConstantsResponse,
)
from .google_ads_field_service import (
    GetGoogleAdsFieldRequest as GetGoogleAdsFieldRequest,
    SearchGoogleAdsFieldsRequest as SearchGoogleAdsFieldsRequest,
    SearchGoogleAdsFieldsResponse as SearchGoogleAdsFieldsResponse,
)
from .google_ads_service import (
    GoogleAdsRow as GoogleAdsRow,
    MutateGoogleAdsRequest as MutateGoogleAdsRequest,
    MutateGoogleAdsResponse as MutateGoogleAdsResponse,
    MutateOperation as MutateOperation,
    MutateOperationResponse as MutateOperationResponse,
    SearchGoogleAdsRequest as SearchGoogleAdsRequest,
    SearchGoogleAdsResponse as SearchGoogleAdsResponse,
    SearchGoogleAdsStreamRequest as SearchGoogleAdsStreamRequest,
    SearchGoogleAdsStreamResponse as SearchGoogleAdsStreamResponse,
    SearchSettings as SearchSettings,
)
from .identity_verification_service import (
    GetIdentityVerificationRequest as GetIdentityVerificationRequest,
    GetIdentityVerificationResponse as GetIdentityVerificationResponse,
    IdentityVerification as IdentityVerification,
    IdentityVerificationProgress as IdentityVerificationProgress,
    IdentityVerificationRequirement as IdentityVerificationRequirement,
    StartIdentityVerificationRequest as StartIdentityVerificationRequest,
)
from .invoice_service import (
    ListInvoicesRequest as ListInvoicesRequest,
    ListInvoicesResponse as ListInvoicesResponse,
)
from .keyword_plan_ad_group_keyword_service import (
    KeywordPlanAdGroupKeywordOperation as KeywordPlanAdGroupKeywordOperation,
    MutateKeywordPlanAdGroupKeywordResult as MutateKeywordPlanAdGroupKeywordResult,
    MutateKeywordPlanAdGroupKeywordsRequest as MutateKeywordPlanAdGroupKeywordsRequest,
    MutateKeywordPlanAdGroupKeywordsResponse as MutateKeywordPlanAdGroupKeywordsResponse,
)
from .keyword_plan_ad_group_service import (
    KeywordPlanAdGroupOperation as KeywordPlanAdGroupOperation,
    MutateKeywordPlanAdGroupResult as MutateKeywordPlanAdGroupResult,
    MutateKeywordPlanAdGroupsRequest as MutateKeywordPlanAdGroupsRequest,
    MutateKeywordPlanAdGroupsResponse as MutateKeywordPlanAdGroupsResponse,
)
from .keyword_plan_campaign_keyword_service import (
    KeywordPlanCampaignKeywordOperation as KeywordPlanCampaignKeywordOperation,
    MutateKeywordPlanCampaignKeywordResult as MutateKeywordPlanCampaignKeywordResult,
    MutateKeywordPlanCampaignKeywordsRequest as MutateKeywordPlanCampaignKeywordsRequest,
    MutateKeywordPlanCampaignKeywordsResponse as MutateKeywordPlanCampaignKeywordsResponse,
)
from .keyword_plan_campaign_service import (
    KeywordPlanCampaignOperation as KeywordPlanCampaignOperation,
    MutateKeywordPlanCampaignResult as MutateKeywordPlanCampaignResult,
    MutateKeywordPlanCampaignsRequest as MutateKeywordPlanCampaignsRequest,
    MutateKeywordPlanCampaignsResponse as MutateKeywordPlanCampaignsResponse,
)
from .keyword_plan_idea_service import (
    AdGroupKeywordSuggestion as AdGroupKeywordSuggestion,
    BiddableKeyword as BiddableKeyword,
    CampaignToForecast as CampaignToForecast,
    CriterionBidModifier as CriterionBidModifier,
    ForecastAdGroup as ForecastAdGroup,
    GenerateAdGroupThemesRequest as GenerateAdGroupThemesRequest,
    GenerateAdGroupThemesResponse as GenerateAdGroupThemesResponse,
    GenerateKeywordForecastMetricsRequest as GenerateKeywordForecastMetricsRequest,
    GenerateKeywordForecastMetricsResponse as GenerateKeywordForecastMetricsResponse,
    GenerateKeywordHistoricalMetricsRequest as GenerateKeywordHistoricalMetricsRequest,
    GenerateKeywordHistoricalMetricsResponse as GenerateKeywordHistoricalMetricsResponse,
    GenerateKeywordHistoricalMetricsResult as GenerateKeywordHistoricalMetricsResult,
    GenerateKeywordIdeaResponse as GenerateKeywordIdeaResponse,
    GenerateKeywordIdeaResult as GenerateKeywordIdeaResult,
    GenerateKeywordIdeasRequest as GenerateKeywordIdeasRequest,
    KeywordAndUrlSeed as KeywordAndUrlSeed,
    KeywordForecastMetrics as KeywordForecastMetrics,
    KeywordSeed as KeywordSeed,
    ManualCpcBiddingStrategy as ManualCpcBiddingStrategy,
    MaximizeClicksBiddingStrategy as MaximizeClicksBiddingStrategy,
    MaximizeConversionsBiddingStrategy as MaximizeConversionsBiddingStrategy,
    SiteSeed as SiteSeed,
    UnusableAdGroup as UnusableAdGroup,
    UrlSeed as UrlSeed,
)
from .keyword_plan_service import (
    KeywordPlanOperation as KeywordPlanOperation,
    MutateKeywordPlansRequest as MutateKeywordPlansRequest,
    MutateKeywordPlansResponse as MutateKeywordPlansResponse,
    MutateKeywordPlansResult as MutateKeywordPlansResult,
)
from .keyword_theme_constant_service import (
    SuggestKeywordThemeConstantsRequest as SuggestKeywordThemeConstantsRequest,
    SuggestKeywordThemeConstantsResponse as SuggestKeywordThemeConstantsResponse,
)
from .label_service import (
    LabelOperation as LabelOperation,
    MutateLabelResult as MutateLabelResult,
    MutateLabelsRequest as MutateLabelsRequest,
    MutateLabelsResponse as MutateLabelsResponse,
)
from .local_services_lead_service import (
    AppendLeadConversationRequest as AppendLeadConversationRequest,
    AppendLeadConversationResponse as AppendLeadConversationResponse,
    Conversation as Conversation,
    ConversationOrError as ConversationOrError,
    ProvideLeadFeedbackRequest as ProvideLeadFeedbackRequest,
    ProvideLeadFeedbackResponse as ProvideLeadFeedbackResponse,
    SurveyDissatisfied as SurveyDissatisfied,
    SurveySatisfied as SurveySatisfied,
)
from .offline_user_data_job_service import (
    AddOfflineUserDataJobOperationsRequest as AddOfflineUserDataJobOperationsRequest,
    AddOfflineUserDataJobOperationsResponse as AddOfflineUserDataJobOperationsResponse,
    CreateOfflineUserDataJobRequest as CreateOfflineUserDataJobRequest,
    CreateOfflineUserDataJobResponse as CreateOfflineUserDataJobResponse,
    OfflineUserDataJobOperation as OfflineUserDataJobOperation,
    RunOfflineUserDataJobRequest as RunOfflineUserDataJobRequest,
)
from .payments_account_service import (
    ListPaymentsAccountsRequest as ListPaymentsAccountsRequest,
    ListPaymentsAccountsResponse as ListPaymentsAccountsResponse,
)
from .product_link_invitation_service import (
    CreateProductLinkInvitationRequest as CreateProductLinkInvitationRequest,
    CreateProductLinkInvitationResponse as CreateProductLinkInvitationResponse,
    RemoveProductLinkInvitationRequest as RemoveProductLinkInvitationRequest,
    RemoveProductLinkInvitationResponse as RemoveProductLinkInvitationResponse,
    UpdateProductLinkInvitationRequest as UpdateProductLinkInvitationRequest,
    UpdateProductLinkInvitationResponse as UpdateProductLinkInvitationResponse,
)
from .product_link_service import (
    CreateProductLinkRequest as CreateProductLinkRequest,
    CreateProductLinkResponse as CreateProductLinkResponse,
    RemoveProductLinkRequest as RemoveProductLinkRequest,
    RemoveProductLinkResponse as RemoveProductLinkResponse,
)
from .reach_plan_service import (
    AdvancedProductTargeting as AdvancedProductTargeting,
    AudienceTargeting as AudienceTargeting,
    CampaignDuration as CampaignDuration,
    ConversionRateSuggestion as ConversionRateSuggestion,
    EffectiveFrequencyBreakdown as EffectiveFrequencyBreakdown,
    EffectiveFrequencyLimit as EffectiveFrequencyLimit,
    Forecast as Forecast,
    ForecastMetricOptions as ForecastMetricOptions,
    FrequencyCap as FrequencyCap,
    GenerateConversionRatesRequest as GenerateConversionRatesRequest,
    GenerateConversionRatesResponse as GenerateConversionRatesResponse,
    GenerateReachForecastRequest as GenerateReachForecastRequest,
    GenerateReachForecastResponse as GenerateReachForecastResponse,
    ListPlannableLocationsRequest as ListPlannableLocationsRequest,
    ListPlannableLocationsResponse as ListPlannableLocationsResponse,
    ListPlannableProductsRequest as ListPlannableProductsRequest,
    ListPlannableProductsResponse as ListPlannableProductsResponse,
    OnTargetAudienceMetrics as OnTargetAudienceMetrics,
    PlannableLocation as PlannableLocation,
    PlannableTargeting as PlannableTargeting,
    PlannedProduct as PlannedProduct,
    PlannedProductForecast as PlannedProductForecast,
    PlannedProductReachForecast as PlannedProductReachForecast,
    ProductMetadata as ProductMetadata,
    ReachCurve as ReachCurve,
    ReachForecast as ReachForecast,
    SurfaceTargeting as SurfaceTargeting,
    SurfaceTargetingCombinations as SurfaceTargetingCombinations,
    TargetFrequencySettings as TargetFrequencySettings,
    Targeting as Targeting,
    YouTubeSelectLineUp as YouTubeSelectLineUp,
    YouTubeSelectSettings as YouTubeSelectSettings,
)
from .recommendation_service import (
    ApplyRecommendationOperation as ApplyRecommendationOperation,
    ApplyRecommendationRequest as ApplyRecommendationRequest,
    ApplyRecommendationResponse as ApplyRecommendationResponse,
    ApplyRecommendationResult as ApplyRecommendationResult,
    DismissRecommendationRequest as DismissRecommendationRequest,
    DismissRecommendationResponse as DismissRecommendationResponse,
    GenerateRecommendationsRequest as GenerateRecommendationsRequest,
    GenerateRecommendationsResponse as GenerateRecommendationsResponse,
)
from .recommendation_subscription_service import (
    MutateRecommendationSubscriptionRequest as MutateRecommendationSubscriptionRequest,
    MutateRecommendationSubscriptionResponse as MutateRecommendationSubscriptionResponse,
    MutateRecommendationSubscriptionResult as MutateRecommendationSubscriptionResult,
    RecommendationSubscriptionOperation as RecommendationSubscriptionOperation,
)
from .remarketing_action_service import (
    MutateRemarketingActionResult as MutateRemarketingActionResult,
    MutateRemarketingActionsRequest as MutateRemarketingActionsRequest,
    MutateRemarketingActionsResponse as MutateRemarketingActionsResponse,
    RemarketingActionOperation as RemarketingActionOperation,
)
from .shareable_preview_service import (
    AssetGroupIdentifier as AssetGroupIdentifier,
    GenerateShareablePreviewsRequest as GenerateShareablePreviewsRequest,
    GenerateShareablePreviewsResponse as GenerateShareablePreviewsResponse,
    ShareablePreview as ShareablePreview,
    ShareablePreviewOrError as ShareablePreviewOrError,
    ShareablePreviewResult as ShareablePreviewResult,
)
from .shared_criterion_service import (
    MutateSharedCriteriaRequest as MutateSharedCriteriaRequest,
    MutateSharedCriteriaResponse as MutateSharedCriteriaResponse,
    MutateSharedCriterionResult as MutateSharedCriterionResult,
    SharedCriterionOperation as SharedCriterionOperation,
)
from .shared_set_service import (
    MutateSharedSetResult as MutateSharedSetResult,
    MutateSharedSetsRequest as MutateSharedSetsRequest,
    MutateSharedSetsResponse as MutateSharedSetsResponse,
    SharedSetOperation as SharedSetOperation,
)
from .smart_campaign_setting_service import (
    GetSmartCampaignStatusRequest as GetSmartCampaignStatusRequest,
    GetSmartCampaignStatusResponse as GetSmartCampaignStatusResponse,
    MutateSmartCampaignSettingResult as MutateSmartCampaignSettingResult,
    MutateSmartCampaignSettingsRequest as MutateSmartCampaignSettingsRequest,
    MutateSmartCampaignSettingsResponse as MutateSmartCampaignSettingsResponse,
    SmartCampaignEligibleDetails as SmartCampaignEligibleDetails,
    SmartCampaignEndedDetails as SmartCampaignEndedDetails,
    SmartCampaignNotEligibleDetails as SmartCampaignNotEligibleDetails,
    SmartCampaignPausedDetails as SmartCampaignPausedDetails,
    SmartCampaignRemovedDetails as SmartCampaignRemovedDetails,
    SmartCampaignSettingOperation as SmartCampaignSettingOperation,
)
from .smart_campaign_suggest_service import (
    SmartCampaignSuggestionInfo as SmartCampaignSuggestionInfo,
    SuggestKeywordThemesRequest as SuggestKeywordThemesRequest,
    SuggestKeywordThemesResponse as SuggestKeywordThemesResponse,
    SuggestSmartCampaignAdRequest as SuggestSmartCampaignAdRequest,
    SuggestSmartCampaignAdResponse as SuggestSmartCampaignAdResponse,
    SuggestSmartCampaignBudgetOptionsRequest as SuggestSmartCampaignBudgetOptionsRequest,
    SuggestSmartCampaignBudgetOptionsResponse as SuggestSmartCampaignBudgetOptionsResponse,
)
from .third_party_app_analytics_link_service import (
    RegenerateShareableLinkIdRequest as RegenerateShareableLinkIdRequest,
    RegenerateShareableLinkIdResponse as RegenerateShareableLinkIdResponse,
)
from .travel_asset_suggestion_service import (
    HotelAssetSuggestion as HotelAssetSuggestion,
    HotelImageAsset as HotelImageAsset,
    HotelTextAsset as HotelTextAsset,
    SuggestTravelAssetsRequest as SuggestTravelAssetsRequest,
    SuggestTravelAssetsResponse as SuggestTravelAssetsResponse,
)
from .user_data_service import (
    UploadUserDataRequest as UploadUserDataRequest,
    UploadUserDataResponse as UploadUserDataResponse,
    UserDataOperation as UserDataOperation,
)
from .user_list_customer_type_service import (
    MutateUserListCustomerTypeResult as MutateUserListCustomerTypeResult,
    MutateUserListCustomerTypesRequest as MutateUserListCustomerTypesRequest,
    MutateUserListCustomerTypesResponse as MutateUserListCustomerTypesResponse,
    UserListCustomerTypeOperation as UserListCustomerTypeOperation,
)
from .user_list_service import (
    MutateUserListResult as MutateUserListResult,
    MutateUserListsRequest as MutateUserListsRequest,
    MutateUserListsResponse as MutateUserListsResponse,
    UserListOperation as UserListOperation,
)

__all__ = [
    "AccountBudgetProposalOperation",
    "MutateAccountBudgetProposalRequest",
    "MutateAccountBudgetProposalResponse",
    "MutateAccountBudgetProposalResult",
    "AccountLinkOperation",
    "CreateAccountLinkRequest",
    "CreateAccountLinkResponse",
    "MutateAccountLinkRequest",
    "MutateAccountLinkResponse",
    "MutateAccountLinkResult",
    "AdGroupAdLabelOperation",
    "MutateAdGroupAdLabelResult",
    "MutateAdGroupAdLabelsRequest",
    "MutateAdGroupAdLabelsResponse",
    "AdGroupAdOperation",
    "AssetsWithFieldType",
    "MutateAdGroupAdResult",
    "MutateAdGroupAdsRequest",
    "MutateAdGroupAdsResponse",
    "RemoveAutomaticallyCreatedAssetsRequest",
    "AdGroupAssetOperation",
    "MutateAdGroupAssetResult",
    "MutateAdGroupAssetsRequest",
    "MutateAdGroupAssetsResponse",
    "AdGroupAssetSetOperation",
    "MutateAdGroupAssetSetResult",
    "MutateAdGroupAssetSetsRequest",
    "MutateAdGroupAssetSetsResponse",
    "AdGroupBidModifierOperation",
    "MutateAdGroupBidModifierResult",
    "MutateAdGroupBidModifiersRequest",
    "MutateAdGroupBidModifiersResponse",
    "AdGroupCriterionCustomizerOperation",
    "MutateAdGroupCriterionCustomizerResult",
    "MutateAdGroupCriterionCustomizersRequest",
    "MutateAdGroupCriterionCustomizersResponse",
    "AdGroupCriterionLabelOperation",
    "MutateAdGroupCriterionLabelResult",
    "MutateAdGroupCriterionLabelsRequest",
    "MutateAdGroupCriterionLabelsResponse",
    "AdGroupCriterionOperation",
    "MutateAdGroupCriteriaRequest",
    "MutateAdGroupCriteriaResponse",
    "MutateAdGroupCriterionResult",
    "AdGroupCustomizerOperation",
    "MutateAdGroupCustomizerResult",
    "MutateAdGroupCustomizersRequest",
    "MutateAdGroupCustomizersResponse",
    "AdGroupLabelOperation",
    "MutateAdGroupLabelResult",
    "MutateAdGroupLabelsRequest",
    "MutateAdGroupLabelsResponse",
    "AdGroupOperation",
    "MutateAdGroupResult",
    "MutateAdGroupsRequest",
    "MutateAdGroupsResponse",
    "AdParameterOperation",
    "MutateAdParameterResult",
    "MutateAdParametersRequest",
    "MutateAdParametersResponse",
    "AdOperation",
    "MutateAdResult",
    "MutateAdsRequest",
    "MutateAdsResponse",
    "AssetGroupAssetOperation",
    "MutateAssetGroupAssetResult",
    "MutateAssetGroupAssetsRequest",
    "MutateAssetGroupAssetsResponse",
    "AssetGroupListingGroupFilterOperation",
    "MutateAssetGroupListingGroupFilterResult",
    "MutateAssetGroupListingGroupFiltersRequest",
    "MutateAssetGroupListingGroupFiltersResponse",
    "AssetGroupOperation",
    "MutateAssetGroupResult",
    "MutateAssetGroupsRequest",
    "MutateAssetGroupsResponse",
    "AssetGroupSignalOperation",
    "MutateAssetGroupSignalResult",
    "MutateAssetGroupSignalsRequest",
    "MutateAssetGroupSignalsResponse",
    "AssetOperation",
    "MutateAssetResult",
    "MutateAssetsRequest",
    "MutateAssetsResponse",
    "AssetSetAssetOperation",
    "MutateAssetSetAssetResult",
    "MutateAssetSetAssetsRequest",
    "MutateAssetSetAssetsResponse",
    "AssetSetOperation",
    "MutateAssetSetResult",
    "MutateAssetSetsRequest",
    "MutateAssetSetsResponse",
    "AudienceCompositionAttribute",
    "AudienceCompositionAttributeCluster",
    "AudienceCompositionMetrics",
    "AudienceCompositionSection",
    "AudienceOverlapItem",
    "BasicInsightsAudience",
    "DimensionOverlapResult",
    "GenerateAudienceCompositionInsightsRequest",
    "GenerateAudienceCompositionInsightsResponse",
    "GenerateAudienceOverlapInsightsRequest",
    "GenerateAudienceOverlapInsightsResponse",
    "GenerateInsightsFinderReportRequest",
    "GenerateInsightsFinderReportResponse",
    "GenerateSuggestedTargetingInsightsRequest",
    "GenerateSuggestedTargetingInsightsResponse",
    "GenerateTargetingSuggestionMetricsRequest",
    "GenerateTargetingSuggestionMetricsResponse",
    "InsightsAudience",
    "InsightsAudienceAttributeGroup",
    "InsightsAudienceDefinition",
    "InsightsAudienceDescription",
    "ListAudienceInsightsAttributesRequest",
    "ListAudienceInsightsAttributesResponse",
    "ListInsightsEligibleDatesRequest",
    "ListInsightsEligibleDatesResponse",
    "TargetingSuggestionMetrics",
    "AudienceOperation",
    "MutateAudienceResult",
    "MutateAudiencesRequest",
    "MutateAudiencesResponse",
    "AddBatchJobOperationsRequest",
    "AddBatchJobOperationsResponse",
    "BatchJobOperation",
    "BatchJobResult",
    "ListBatchJobResultsRequest",
    "ListBatchJobResultsResponse",
    "MutateBatchJobRequest",
    "MutateBatchJobResponse",
    "MutateBatchJobResult",
    "RunBatchJobRequest",
    "BiddingDataExclusionOperation",
    "MutateBiddingDataExclusionsRequest",
    "MutateBiddingDataExclusionsResponse",
    "MutateBiddingDataExclusionsResult",
    "BiddingSeasonalityAdjustmentOperation",
    "MutateBiddingSeasonalityAdjustmentsRequest",
    "MutateBiddingSeasonalityAdjustmentsResponse",
    "MutateBiddingSeasonalityAdjustmentsResult",
    "BiddingStrategyOperation",
    "MutateBiddingStrategiesRequest",
    "MutateBiddingStrategiesResponse",
    "MutateBiddingStrategyResult",
    "BillingSetupOperation",
    "MutateBillingSetupRequest",
    "MutateBillingSetupResponse",
    "MutateBillingSetupResult",
    "BrandSuggestion",
    "SuggestBrandsRequest",
    "SuggestBrandsResponse",
    "CampaignAssetOperation",
    "MutateCampaignAssetResult",
    "MutateCampaignAssetsRequest",
    "MutateCampaignAssetsResponse",
    "CampaignAssetSetOperation",
    "MutateCampaignAssetSetResult",
    "MutateCampaignAssetSetsRequest",
    "MutateCampaignAssetSetsResponse",
    "CampaignBidModifierOperation",
    "MutateCampaignBidModifierResult",
    "MutateCampaignBidModifiersRequest",
    "MutateCampaignBidModifiersResponse",
    "CampaignBudgetOperation",
    "MutateCampaignBudgetResult",
    "MutateCampaignBudgetsRequest",
    "MutateCampaignBudgetsResponse",
    "CampaignConversionGoalOperation",
    "MutateCampaignConversionGoalResult",
    "MutateCampaignConversionGoalsRequest",
    "MutateCampaignConversionGoalsResponse",
    "CampaignCriterionOperation",
    "MutateCampaignCriteriaRequest",
    "MutateCampaignCriteriaResponse",
    "MutateCampaignCriterionResult",
    "CampaignCustomizerOperation",
    "MutateCampaignCustomizerResult",
    "MutateCampaignCustomizersRequest",
    "MutateCampaignCustomizersResponse",
    "CampaignDraftOperation",
    "ListCampaignDraftAsyncErrorsRequest",
    "ListCampaignDraftAsyncErrorsResponse",
    "MutateCampaignDraftResult",
    "MutateCampaignDraftsRequest",
    "MutateCampaignDraftsResponse",
    "PromoteCampaignDraftRequest",
    "CampaignGroupOperation",
    "MutateCampaignGroupResult",
    "MutateCampaignGroupsRequest",
    "MutateCampaignGroupsResponse",
    "CampaignLabelOperation",
    "MutateCampaignLabelResult",
    "MutateCampaignLabelsRequest",
    "MutateCampaignLabelsResponse",
    "CampaignLifecycleGoalOperation",
    "ConfigureCampaignLifecycleGoalsRequest",
    "ConfigureCampaignLifecycleGoalsResponse",
    "ConfigureCampaignLifecycleGoalsResult",
    "BrandCampaignAssets",
    "CampaignOperation",
    "EnablementResult",
    "EnableOperation",
    "EnablePMaxBrandGuidelinesRequest",
    "EnablePMaxBrandGuidelinesResponse",
    "MutateCampaignResult",
    "MutateCampaignsRequest",
    "MutateCampaignsResponse",
    "CampaignSharedSetOperation",
    "MutateCampaignSharedSetResult",
    "MutateCampaignSharedSetsRequest",
    "MutateCampaignSharedSetsResponse",
    "GenerateCreatorInsightsRequest",
    "GenerateCreatorInsightsResponse",
    "GenerateTrendingInsightsRequest",
    "GenerateTrendingInsightsResponse",
    "SearchAudience",
    "SearchTopics",
    "TrendInsight",
    "TrendInsightMetrics",
    "YouTubeChannelInsights",
    "YouTubeCreatorInsights",
    "YouTubeMetrics",
    "ConversionActionOperation",
    "MutateConversionActionResult",
    "MutateConversionActionsRequest",
    "MutateConversionActionsResponse",
    "ConversionAdjustment",
    "ConversionAdjustmentResult",
    "GclidDateTimePair",
    "RestatementValue",
    "UploadConversionAdjustmentsRequest",
    "UploadConversionAdjustmentsResponse",
    "ConversionCustomVariableOperation",
    "MutateConversionCustomVariableResult",
    "MutateConversionCustomVariablesRequest",
    "MutateConversionCustomVariablesResponse",
    "ConversionGoalCampaignConfigOperation",
    "MutateConversionGoalCampaignConfigResult",
    "MutateConversionGoalCampaignConfigsRequest",
    "MutateConversionGoalCampaignConfigsResponse",
    "CallConversion",
    "CallConversionResult",
    "CartData",
    "ClickConversion",
    "ClickConversionResult",
    "CustomVariable",
    "ExternalAttributionData",
    "SessionAttributeKeyValuePair",
    "SessionAttributesKeyValuePairs",
    "UploadCallConversionsRequest",
    "UploadCallConversionsResponse",
    "UploadClickConversionsRequest",
    "UploadClickConversionsResponse",
    "ConversionValueRuleOperation",
    "MutateConversionValueRuleResult",
    "MutateConversionValueRulesRequest",
    "MutateConversionValueRulesResponse",
    "ConversionValueRuleSetOperation",
    "MutateConversionValueRuleSetResult",
    "MutateConversionValueRuleSetsRequest",
    "MutateConversionValueRuleSetsResponse",
    "CustomAudienceOperation",
    "MutateCustomAudienceResult",
    "MutateCustomAudiencesRequest",
    "MutateCustomAudiencesResponse",
    "CustomConversionGoalOperation",
    "MutateCustomConversionGoalResult",
    "MutateCustomConversionGoalsRequest",
    "MutateCustomConversionGoalsResponse",
    "CustomInterestOperation",
    "MutateCustomInterestResult",
    "MutateCustomInterestsRequest",
    "MutateCustomInterestsResponse",
    "CustomerAssetOperation",
    "MutateCustomerAssetResult",
    "MutateCustomerAssetsRequest",
    "MutateCustomerAssetsResponse",
    "CustomerAssetSetOperation",
    "MutateCustomerAssetSetResult",
    "MutateCustomerAssetSetsRequest",
    "MutateCustomerAssetSetsResponse",
    "CustomerClientLinkOperation",
    "MutateCustomerClientLinkRequest",
    "MutateCustomerClientLinkResponse",
    "MutateCustomerClientLinkResult",
    "CustomerConversionGoalOperation",
    "MutateCustomerConversionGoalResult",
    "MutateCustomerConversionGoalsRequest",
    "MutateCustomerConversionGoalsResponse",
    "CustomerCustomizerOperation",
    "MutateCustomerCustomizerResult",
    "MutateCustomerCustomizersRequest",
    "MutateCustomerCustomizersResponse",
    "CustomerLabelOperation",
    "MutateCustomerLabelResult",
    "MutateCustomerLabelsRequest",
    "MutateCustomerLabelsResponse",
    "ConfigureCustomerLifecycleGoalsRequest",
    "ConfigureCustomerLifecycleGoalsResponse",
    "ConfigureCustomerLifecycleGoalsResult",
    "CustomerLifecycleGoalOperation",
    "CustomerManagerLinkOperation",
    "MoveManagerLinkRequest",
    "MoveManagerLinkResponse",
    "MutateCustomerManagerLinkRequest",
    "MutateCustomerManagerLinkResponse",
    "MutateCustomerManagerLinkResult",
    "CustomerNegativeCriterionOperation",
    "MutateCustomerNegativeCriteriaRequest",
    "MutateCustomerNegativeCriteriaResponse",
    "MutateCustomerNegativeCriteriaResult",
    "CreateCustomerClientRequest",
    "CreateCustomerClientResponse",
    "CustomerOperation",
    "ListAccessibleCustomersRequest",
    "ListAccessibleCustomersResponse",
    "MutateCustomerRequest",
    "MutateCustomerResponse",
    "MutateCustomerResult",
    "CustomerSkAdNetworkConversionValueSchemaOperation",
    "MutateCustomerSkAdNetworkConversionValueSchemaRequest",
    "MutateCustomerSkAdNetworkConversionValueSchemaResponse",
    "MutateCustomerSkAdNetworkConversionValueSchemaResult",
    "CustomerUserAccessInvitationOperation",
    "MutateCustomerUserAccessInvitationRequest",
    "MutateCustomerUserAccessInvitationResponse",
    "MutateCustomerUserAccessInvitationResult",
    "CustomerUserAccessOperation",
    "MutateCustomerUserAccessRequest",
    "MutateCustomerUserAccessResponse",
    "MutateCustomerUserAccessResult",
    "CustomizerAttributeOperation",
    "MutateCustomizerAttributeResult",
    "MutateCustomizerAttributesRequest",
    "MutateCustomizerAttributesResponse",
    "CreateDataLinkRequest",
    "CreateDataLinkResponse",
    "RemoveDataLinkRequest",
    "RemoveDataLinkResponse",
    "UpdateDataLinkRequest",
    "UpdateDataLinkResponse",
    "ExperimentArmOperation",
    "MutateExperimentArmResult",
    "MutateExperimentArmsRequest",
    "MutateExperimentArmsResponse",
    "CampaignBudgetMapping",
    "EndExperimentRequest",
    "ExperimentOperation",
    "GraduateExperimentRequest",
    "ListExperimentAsyncErrorsRequest",
    "ListExperimentAsyncErrorsResponse",
    "MutateExperimentResult",
    "MutateExperimentsRequest",
    "MutateExperimentsResponse",
    "PromoteExperimentMetadata",
    "PromoteExperimentRequest",
    "ScheduleExperimentMetadata",
    "ScheduleExperimentRequest",
    "GeoTargetConstantSuggestion",
    "SuggestGeoTargetConstantsRequest",
    "SuggestGeoTargetConstantsResponse",
    "GetGoogleAdsFieldRequest",
    "SearchGoogleAdsFieldsRequest",
    "SearchGoogleAdsFieldsResponse",
    "GoogleAdsRow",
    "MutateGoogleAdsRequest",
    "MutateGoogleAdsResponse",
    "MutateOperation",
    "MutateOperationResponse",
    "SearchGoogleAdsRequest",
    "SearchGoogleAdsResponse",
    "SearchGoogleAdsStreamRequest",
    "SearchGoogleAdsStreamResponse",
    "SearchSettings",
    "GetIdentityVerificationRequest",
    "GetIdentityVerificationResponse",
    "IdentityVerification",
    "IdentityVerificationProgress",
    "IdentityVerificationRequirement",
    "StartIdentityVerificationRequest",
    "ListInvoicesRequest",
    "ListInvoicesResponse",
    "KeywordPlanAdGroupKeywordOperation",
    "MutateKeywordPlanAdGroupKeywordResult",
    "MutateKeywordPlanAdGroupKeywordsRequest",
    "MutateKeywordPlanAdGroupKeywordsResponse",
    "KeywordPlanAdGroupOperation",
    "MutateKeywordPlanAdGroupResult",
    "MutateKeywordPlanAdGroupsRequest",
    "MutateKeywordPlanAdGroupsResponse",
    "KeywordPlanCampaignKeywordOperation",
    "MutateKeywordPlanCampaignKeywordResult",
    "MutateKeywordPlanCampaignKeywordsRequest",
    "MutateKeywordPlanCampaignKeywordsResponse",
    "KeywordPlanCampaignOperation",
    "MutateKeywordPlanCampaignResult",
    "MutateKeywordPlanCampaignsRequest",
    "MutateKeywordPlanCampaignsResponse",
    "AdGroupKeywordSuggestion",
    "BiddableKeyword",
    "CampaignToForecast",
    "CriterionBidModifier",
    "ForecastAdGroup",
    "GenerateAdGroupThemesRequest",
    "GenerateAdGroupThemesResponse",
    "GenerateKeywordForecastMetricsRequest",
    "GenerateKeywordForecastMetricsResponse",
    "GenerateKeywordHistoricalMetricsRequest",
    "GenerateKeywordHistoricalMetricsResponse",
    "GenerateKeywordHistoricalMetricsResult",
    "GenerateKeywordIdeaResponse",
    "GenerateKeywordIdeaResult",
    "GenerateKeywordIdeasRequest",
    "KeywordAndUrlSeed",
    "KeywordForecastMetrics",
    "KeywordSeed",
    "ManualCpcBiddingStrategy",
    "MaximizeClicksBiddingStrategy",
    "MaximizeConversionsBiddingStrategy",
    "SiteSeed",
    "UnusableAdGroup",
    "UrlSeed",
    "KeywordPlanOperation",
    "MutateKeywordPlansRequest",
    "MutateKeywordPlansResponse",
    "MutateKeywordPlansResult",
    "SuggestKeywordThemeConstantsRequest",
    "SuggestKeywordThemeConstantsResponse",
    "LabelOperation",
    "MutateLabelResult",
    "MutateLabelsRequest",
    "MutateLabelsResponse",
    "AppendLeadConversationRequest",
    "AppendLeadConversationResponse",
    "Conversation",
    "ConversationOrError",
    "ProvideLeadFeedbackRequest",
    "ProvideLeadFeedbackResponse",
    "SurveyDissatisfied",
    "SurveySatisfied",
    "AddOfflineUserDataJobOperationsRequest",
    "AddOfflineUserDataJobOperationsResponse",
    "CreateOfflineUserDataJobRequest",
    "CreateOfflineUserDataJobResponse",
    "OfflineUserDataJobOperation",
    "RunOfflineUserDataJobRequest",
    "ListPaymentsAccountsRequest",
    "ListPaymentsAccountsResponse",
    "CreateProductLinkInvitationRequest",
    "CreateProductLinkInvitationResponse",
    "RemoveProductLinkInvitationRequest",
    "RemoveProductLinkInvitationResponse",
    "UpdateProductLinkInvitationRequest",
    "UpdateProductLinkInvitationResponse",
    "CreateProductLinkRequest",
    "CreateProductLinkResponse",
    "RemoveProductLinkRequest",
    "RemoveProductLinkResponse",
    "AdvancedProductTargeting",
    "AudienceTargeting",
    "CampaignDuration",
    "ConversionRateSuggestion",
    "EffectiveFrequencyBreakdown",
    "EffectiveFrequencyLimit",
    "Forecast",
    "ForecastMetricOptions",
    "FrequencyCap",
    "GenerateConversionRatesRequest",
    "GenerateConversionRatesResponse",
    "GenerateReachForecastRequest",
    "GenerateReachForecastResponse",
    "ListPlannableLocationsRequest",
    "ListPlannableLocationsResponse",
    "ListPlannableProductsRequest",
    "ListPlannableProductsResponse",
    "OnTargetAudienceMetrics",
    "PlannableLocation",
    "PlannableTargeting",
    "PlannedProduct",
    "PlannedProductForecast",
    "PlannedProductReachForecast",
    "ProductMetadata",
    "ReachCurve",
    "ReachForecast",
    "SurfaceTargeting",
    "SurfaceTargetingCombinations",
    "TargetFrequencySettings",
    "Targeting",
    "YouTubeSelectLineUp",
    "YouTubeSelectSettings",
    "ApplyRecommendationOperation",
    "ApplyRecommendationRequest",
    "ApplyRecommendationResponse",
    "ApplyRecommendationResult",
    "DismissRecommendationRequest",
    "DismissRecommendationResponse",
    "GenerateRecommendationsRequest",
    "GenerateRecommendationsResponse",
    "MutateRecommendationSubscriptionRequest",
    "MutateRecommendationSubscriptionResponse",
    "MutateRecommendationSubscriptionResult",
    "RecommendationSubscriptionOperation",
    "MutateRemarketingActionResult",
    "MutateRemarketingActionsRequest",
    "MutateRemarketingActionsResponse",
    "RemarketingActionOperation",
    "AssetGroupIdentifier",
    "GenerateShareablePreviewsRequest",
    "GenerateShareablePreviewsResponse",
    "ShareablePreview",
    "ShareablePreviewOrError",
    "ShareablePreviewResult",
    "MutateSharedCriteriaRequest",
    "MutateSharedCriteriaResponse",
    "MutateSharedCriterionResult",
    "SharedCriterionOperation",
    "MutateSharedSetResult",
    "MutateSharedSetsRequest",
    "MutateSharedSetsResponse",
    "SharedSetOperation",
    "GetSmartCampaignStatusRequest",
    "GetSmartCampaignStatusResponse",
    "MutateSmartCampaignSettingResult",
    "MutateSmartCampaignSettingsRequest",
    "MutateSmartCampaignSettingsResponse",
    "SmartCampaignEligibleDetails",
    "SmartCampaignEndedDetails",
    "SmartCampaignNotEligibleDetails",
    "SmartCampaignPausedDetails",
    "SmartCampaignRemovedDetails",
    "SmartCampaignSettingOperation",
    "SmartCampaignSuggestionInfo",
    "SuggestKeywordThemesRequest",
    "SuggestKeywordThemesResponse",
    "SuggestSmartCampaignAdRequest",
    "SuggestSmartCampaignAdResponse",
    "SuggestSmartCampaignBudgetOptionsRequest",
    "SuggestSmartCampaignBudgetOptionsResponse",
    "RegenerateShareableLinkIdRequest",
    "RegenerateShareableLinkIdResponse",
    "HotelAssetSuggestion",
    "HotelImageAsset",
    "HotelTextAsset",
    "SuggestTravelAssetsRequest",
    "SuggestTravelAssetsResponse",
    "UploadUserDataRequest",
    "UploadUserDataResponse",
    "UserDataOperation",
    "MutateUserListCustomerTypeResult",
    "MutateUserListCustomerTypesRequest",
    "MutateUserListCustomerTypesResponse",
    "UserListCustomerTypeOperation",
    "MutateUserListResult",
    "MutateUserListsRequest",
    "MutateUserListsResponse",
    "UserListOperation",
]



from .async_client import (
    BiddingStrategyServiceAsyncClient as BiddingStrategyServiceAsyncClient,
)
from .client import BiddingStrategyServiceClient as BiddingStrategyServiceClient

__all__ = ["BiddingStrategyServiceClient", "BiddingStrategyServiceAsyncClient"]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v21.enums.types.ad_strength import AdStrengthEnum
from google.ads.googleads.v21.enums.types.ad_strength_action_item_type import (
    AdStrengthActionItemTypeEnum,
)
from google.ads.googleads.v21.enums.types.asset_coverage_video_aspect_ratio_requirement import (
    AssetCoverageVideoAspectRatioRequirementEnum,
)
from google.ads.googleads.v21.enums.types.asset_field_type import AssetFieldTypeEnum
from google.ads.googleads.v21.enums.types.asset_group_primary_status import (
    AssetGroupPrimaryStatusEnum,
)
from google.ads.googleads.v21.enums.types.asset_group_primary_status_reason import (
    AssetGroupPrimaryStatusReasonEnum,
)
from google.ads.googleads.v21.enums.types.asset_group_status import AssetGroupStatusEnum

_M = TypeVar("_M")

class AdStrengthActionItem(proto.Message):
    class AddAssetDetails(proto.Message):
        asset_field_type: AssetFieldTypeEnum.AssetFieldType
        asset_count: int
        video_aspect_ratio_requirement: AssetCoverageVideoAspectRatioRequirementEnum.AssetCoverageVideoAspectRatioRequirement
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            asset_field_type: AssetFieldTypeEnum.AssetFieldType = ...,
            asset_count: int = ...,
            video_aspect_ratio_requirement: AssetCoverageVideoAspectRatioRequirementEnum.AssetCoverageVideoAspectRatioRequirement = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self,
            key: Literal[
                "asset_field_type", "asset_count", "video_aspect_ratio_requirement"
            ],
        ) -> bool: ...

    action_item_type: AdStrengthActionItemTypeEnum.AdStrengthActionItemType
    add_asset_details: AdStrengthActionItem.AddAssetDetails
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        action_item_type: AdStrengthActionItemTypeEnum.AdStrengthActionItemType = ...,
        add_asset_details: AdStrengthActionItem.AddAssetDetails = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["action_item_type", "add_asset_details"]
    ) -> bool: ...

class AssetCoverage(proto.Message):
    ad_strength_action_items: MutableSequence[AdStrengthActionItem]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        ad_strength_action_items: MutableSequence[AdStrengthActionItem] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["ad_strength_action_items"]
    ) -> bool: ...

class AssetGroup(proto.Message):
    resource_name: str
    id: int
    campaign: str
    name: str
    final_urls: MutableSequence[str]
    final_mobile_urls: MutableSequence[str]
    status: AssetGroupStatusEnum.AssetGroupStatus
    primary_status: AssetGroupPrimaryStatusEnum.AssetGroupPrimaryStatus
    primary_status_reasons: MutableSequence[
        AssetGroupPrimaryStatusReasonEnum.AssetGroupPrimaryStatusReason
    ]
    path1: str
    path2: str
    ad_strength: AdStrengthEnum.AdStrength
    asset_coverage: AssetCoverage
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        id: int = ...,
        campaign: str = ...,
        name: str = ...,
        final_urls: MutableSequence[str] = ...,
        final_mobile_urls: MutableSequence[str] = ...,
        status: AssetGroupStatusEnum.AssetGroupStatus = ...,
        primary_status: AssetGroupPrimaryStatusEnum.AssetGroupPrimaryStatus = ...,
        primary_status_reasons: MutableSequence[
            AssetGroupPrimaryStatusReasonEnum.AssetGroupPrimaryStatusReason
        ] = ...,
        path1: str = ...,
        path2: str = ...,
        ad_strength: AdStrengthEnum.AdStrength = ...,
        asset_coverage: AssetCoverage = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "id",
            "campaign",
            "name",
            "final_urls",
            "final_mobile_urls",
            "status",
            "primary_status",
            "primary_status_reasons",
            "path1",
            "path2",
            "ad_strength",
            "asset_coverage",
        ],
    ) -> bool: ...



from .async_client import UserDataServiceAsyncClient as UserDataServiceAsyncClient
from .client import UserDataServiceClient as UserDataServiceClient

__all__ = ["UserDataServiceClient", "UserDataServiceAsyncClient"]



from .base import UserDataServiceTransport as UserDataServiceTransport
from .grpc import UserDataServiceGrpcTransport as UserDataServiceGrpcTransport
from .grpc_asyncio import (
    UserDataServiceGrpcAsyncIOTransport as UserDataServiceGrpcAsyncIOTransport,
)

__all__ = [
    "UserDataServiceTransport",
    "UserDataServiceGrpcTransport",
    "UserDataServiceGrpcAsyncIOTransport",
]



from .base import (
    RecommendationSubscriptionServiceTransport as RecommendationSubscriptionServiceTransport,
)
from .grpc import (
    RecommendationSubscriptionServiceGrpcTransport as RecommendationSubscriptionServiceGrpcTransport,
)
from .grpc_asyncio import (
    RecommendationSubscriptionServiceGrpcAsyncIOTransport as RecommendationSubscriptionServiceGrpcAsyncIOTransport,
)

__all__ = [
    "RecommendationSubscriptionServiceTransport",
    "RecommendationSubscriptionServiceGrpcTransport",
    "RecommendationSubscriptionServiceGrpcAsyncIOTransport",
]



from .async_client import (
    BiddingSeasonalityAdjustmentServiceAsyncClient as BiddingSeasonalityAdjustmentServiceAsyncClient,
)
from .client import (
    BiddingSeasonalityAdjustmentServiceClient as BiddingSeasonalityAdjustmentServiceClient,
)

__all__ = [
    "BiddingSeasonalityAdjustmentServiceClient",
    "BiddingSeasonalityAdjustmentServiceAsyncClient",
]



import abc
from typing import Awaitable, Callable, Sequence

from _typeshed import Incomplete
from google.api_core import gapic_v1
from google.auth import credentials as ga_credentials
from google.longrunning import operations_pb2
from google.protobuf import empty_pb2

from google.ads.googleads.v19.services.types import experiment_service

__all__ = ["ExperimentServiceTransport"]

class ExperimentServiceTransport(abc.ABC):
    AUTH_SCOPES: Incomplete
    DEFAULT_HOST: str
    def __init__(
        self,
        *,
        host: str = "googleads.googleapis.com",
        credentials: ga_credentials.Credentials | None = None,
        credentials_file: str | None = None,
        scopes: Sequence[str] | None = None,
        quota_project_id: str | None = None,
        client_info: gapic_v1.client_info.ClientInfo = ...,
        always_use_jwt_access: bool | None = False,
        api_audience: str | None = None,
        **kwargs,
    ) -> None: ...
    @property
    def host(self): ...
    def close(self) -> None: ...
    @property
    def operations_client(self) -> None: ...
    @property
    def mutate_experiments(
        self,
    ) -> Callable[
        [experiment_service.MutateExperimentsRequest],
        experiment_service.MutateExperimentsResponse
        | Awaitable[experiment_service.MutateExperimentsResponse],
    ]: ...
    @property
    def end_experiment(
        self,
    ) -> Callable[
        [experiment_service.EndExperimentRequest],
        empty_pb2.Empty | Awaitable[empty_pb2.Empty],
    ]: ...
    @property
    def list_experiment_async_errors(
        self,
    ) -> Callable[
        [experiment_service.ListExperimentAsyncErrorsRequest],
        experiment_service.ListExperimentAsyncErrorsResponse
        | Awaitable[experiment_service.ListExperimentAsyncErrorsResponse],
    ]: ...
    @property
    def graduate_experiment(
        self,
    ) -> Callable[
        [experiment_service.GraduateExperimentRequest],
        empty_pb2.Empty | Awaitable[empty_pb2.Empty],
    ]: ...
    @property
    def schedule_experiment(
        self,
    ) -> Callable[
        [experiment_service.ScheduleExperimentRequest],
        operations_pb2.Operation | Awaitable[operations_pb2.Operation],
    ]: ...
    @property
    def promote_experiment(
        self,
    ) -> Callable[
        [experiment_service.PromoteExperimentRequest],
        operations_pb2.Operation | Awaitable[operations_pb2.Operation],
    ]: ...
    @property
    def kind(self) -> str: ...



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from google.protobuf.field_mask_pb2 import FieldMask
from typing_extensions import Literal

from google.ads.googleads.v19.resources.types.customer_manager_link import (
    CustomerManagerLink,
)

_M = TypeVar("_M")

class CustomerManagerLinkOperation(proto.Message):
    update_mask: FieldMask
    update: CustomerManagerLink
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        update_mask: FieldMask = ...,
        update: CustomerManagerLink = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["update_mask", "update"]
    ) -> bool: ...

class MoveManagerLinkRequest(proto.Message):
    customer_id: str
    previous_customer_manager_link: str
    new_manager: str
    validate_only: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        previous_customer_manager_link: str = ...,
        new_manager: str = ...,
        validate_only: bool = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "customer_id",
            "previous_customer_manager_link",
            "new_manager",
            "validate_only",
        ],
    ) -> bool: ...

class MoveManagerLinkResponse(proto.Message):
    resource_name: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["resource_name"]
    ) -> bool: ...

class MutateCustomerManagerLinkRequest(proto.Message):
    customer_id: str
    operations: MutableSequence[CustomerManagerLinkOperation]
    validate_only: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        operations: MutableSequence[CustomerManagerLinkOperation] = ...,
        validate_only: bool = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["customer_id", "operations", "validate_only"]
    ) -> bool: ...

class MutateCustomerManagerLinkResponse(proto.Message):
    results: MutableSequence[MutateCustomerManagerLinkResult]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        results: MutableSequence[MutateCustomerManagerLinkResult] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["results"]
    ) -> bool: ...

class MutateCustomerManagerLinkResult(proto.Message):
    resource_name: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["resource_name"]
    ) -> bool: ...



from .async_client import (
    CustomizerAttributeServiceAsyncClient as CustomizerAttributeServiceAsyncClient,
)
from .client import CustomizerAttributeServiceClient as CustomizerAttributeServiceClient

__all__ = ["CustomizerAttributeServiceClient", "CustomizerAttributeServiceAsyncClient"]



from .async_client import (
    AccountBudgetProposalServiceAsyncClient as AccountBudgetProposalServiceAsyncClient,
)
from .client import (
    AccountBudgetProposalServiceClient as AccountBudgetProposalServiceClient,
)

__all__ = [
    "AccountBudgetProposalServiceClient",
    "AccountBudgetProposalServiceAsyncClient",
]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v19.enums.types.android_privacy_interaction_type import (
    AndroidPrivacyInteractionTypeEnum,
)

_M = TypeVar("_M")

class AndroidPrivacySharedKeyGoogleCampaign(proto.Message):
    resource_name: str
    campaign_id: int
    android_privacy_interaction_type: (
        AndroidPrivacyInteractionTypeEnum.AndroidPrivacyInteractionType
    )
    android_privacy_interaction_date: str
    shared_campaign_key: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        campaign_id: int = ...,
        android_privacy_interaction_type: AndroidPrivacyInteractionTypeEnum.AndroidPrivacyInteractionType = ...,
        android_privacy_interaction_date: str = ...,
        shared_campaign_key: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "campaign_id",
            "android_privacy_interaction_type",
            "android_privacy_interaction_date",
            "shared_campaign_key",
        ],
    ) -> bool: ...



from .async_client import (
    AdGroupCustomizerServiceAsyncClient as AdGroupCustomizerServiceAsyncClient,
)
from .client import AdGroupCustomizerServiceClient as AdGroupCustomizerServiceClient

__all__ = ["AdGroupCustomizerServiceClient", "AdGroupCustomizerServiceAsyncClient"]



from .base import SharedSetServiceTransport as SharedSetServiceTransport
from .grpc import SharedSetServiceGrpcTransport as SharedSetServiceGrpcTransport
from .grpc_asyncio import (
    SharedSetServiceGrpcAsyncIOTransport as SharedSetServiceGrpcAsyncIOTransport,
)

__all__ = [
    "SharedSetServiceTransport",
    "SharedSetServiceGrpcTransport",
    "SharedSetServiceGrpcAsyncIOTransport",
]



from .base import InvoiceServiceTransport as InvoiceServiceTransport
from .grpc import InvoiceServiceGrpcTransport as InvoiceServiceGrpcTransport
from .grpc_asyncio import (
    InvoiceServiceGrpcAsyncIOTransport as InvoiceServiceGrpcAsyncIOTransport,
)

__all__ = [
    "InvoiceServiceTransport",
    "InvoiceServiceGrpcTransport",
    "InvoiceServiceGrpcAsyncIOTransport",
]



from .async_client import (
    LocalServicesLeadServiceAsyncClient as LocalServicesLeadServiceAsyncClient,
)
from .client import LocalServicesLeadServiceClient as LocalServicesLeadServiceClient

__all__ = ["LocalServicesLeadServiceClient", "LocalServicesLeadServiceAsyncClient"]



from .async_client import (
    TravelAssetSuggestionServiceAsyncClient as TravelAssetSuggestionServiceAsyncClient,
)
from .client import (
    TravelAssetSuggestionServiceClient as TravelAssetSuggestionServiceClient,
)

__all__ = [
    "TravelAssetSuggestionServiceClient",
    "TravelAssetSuggestionServiceAsyncClient",
]



from .async_client import (
    AssetGroupAssetServiceAsyncClient as AssetGroupAssetServiceAsyncClient,
)
from .client import AssetGroupAssetServiceClient as AssetGroupAssetServiceClient

__all__ = ["AssetGroupAssetServiceClient", "AssetGroupAssetServiceAsyncClient"]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v19.common.types.lifecycle_goals import (
    LifecycleGoalValueSettings,
)

_M = TypeVar("_M")

class CustomerLifecycleGoal(proto.Message):
    resource_name: str
    customer_acquisition_goal_value_settings: LifecycleGoalValueSettings
    owner_customer: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        customer_acquisition_goal_value_settings: LifecycleGoalValueSettings = ...,
        owner_customer: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "customer_acquisition_goal_value_settings",
            "owner_customer",
        ],
    ) -> bool: ...



from .async_client import (
    AdGroupCriterionCustomizerServiceAsyncClient as AdGroupCriterionCustomizerServiceAsyncClient,
)
from .client import (
    AdGroupCriterionCustomizerServiceClient as AdGroupCriterionCustomizerServiceClient,
)

__all__ = [
    "AdGroupCriterionCustomizerServiceClient",
    "AdGroupCriterionCustomizerServiceAsyncClient",
]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

_M = TypeVar("_M")

class Money(proto.Message):
    currency_code: str
    amount_micros: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        currency_code: str = ...,
        amount_micros: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["currency_code", "amount_micros"]
    ) -> bool: ...



from .async_client import (
    PaymentsAccountServiceAsyncClient as PaymentsAccountServiceAsyncClient,
)
from .client import PaymentsAccountServiceClient as PaymentsAccountServiceClient

__all__ = ["PaymentsAccountServiceClient", "PaymentsAccountServiceAsyncClient"]



from .async_client import UserListServiceAsyncClient as UserListServiceAsyncClient
from .client import UserListServiceClient as UserListServiceClient

__all__ = ["UserListServiceClient", "UserListServiceAsyncClient"]



from .async_client import (
    ThirdPartyAppAnalyticsLinkServiceAsyncClient as ThirdPartyAppAnalyticsLinkServiceAsyncClient,
)
from .client import (
    ThirdPartyAppAnalyticsLinkServiceClient as ThirdPartyAppAnalyticsLinkServiceClient,
)

__all__ = [
    "ThirdPartyAppAnalyticsLinkServiceClient",
    "ThirdPartyAppAnalyticsLinkServiceAsyncClient",
]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v21.enums.types.third_party_brand_lift_integration_partner import (
    ThirdPartyBrandLiftIntegrationPartnerEnum,
)
from google.ads.googleads.v21.enums.types.third_party_brand_safety_integration_partner import (
    ThirdPartyBrandSafetyIntegrationPartnerEnum,
)
from google.ads.googleads.v21.enums.types.third_party_reach_integration_partner import (
    ThirdPartyReachIntegrationPartnerEnum,
)
from google.ads.googleads.v21.enums.types.third_party_viewability_integration_partner import (
    ThirdPartyViewabilityIntegrationPartnerEnum,
)

_M = TypeVar("_M")

class CampaignThirdPartyBrandLiftIntegrationPartner(proto.Message):
    brand_lift_integration_partner: (
        ThirdPartyBrandLiftIntegrationPartnerEnum.ThirdPartyBrandLiftIntegrationPartner
    )
    brand_lift_integration_partner_data: ThirdPartyIntegrationPartnerData
    share_cost: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        brand_lift_integration_partner: ThirdPartyBrandLiftIntegrationPartnerEnum.ThirdPartyBrandLiftIntegrationPartner = ...,
        brand_lift_integration_partner_data: ThirdPartyIntegrationPartnerData = ...,
        share_cost: bool = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "brand_lift_integration_partner",
            "brand_lift_integration_partner_data",
            "share_cost",
        ],
    ) -> bool: ...

class CampaignThirdPartyBrandSafetyIntegrationPartner(proto.Message):
    brand_safety_integration_partner: ThirdPartyBrandSafetyIntegrationPartnerEnum.ThirdPartyBrandSafetyIntegrationPartner
    brand_safety_integration_partner_data: ThirdPartyIntegrationPartnerData
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        brand_safety_integration_partner: ThirdPartyBrandSafetyIntegrationPartnerEnum.ThirdPartyBrandSafetyIntegrationPartner = ...,
        brand_safety_integration_partner_data: ThirdPartyIntegrationPartnerData = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "brand_safety_integration_partner", "brand_safety_integration_partner_data"
        ],
    ) -> bool: ...

class CampaignThirdPartyIntegrationPartners(proto.Message):
    viewability_integration_partners: MutableSequence[
        CampaignThirdPartyViewabilityIntegrationPartner
    ]
    brand_lift_integration_partners: MutableSequence[
        CampaignThirdPartyBrandLiftIntegrationPartner
    ]
    brand_safety_integration_partners: MutableSequence[
        CampaignThirdPartyBrandSafetyIntegrationPartner
    ]
    reach_integration_partners: MutableSequence[
        CampaignThirdPartyReachIntegrationPartner
    ]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        viewability_integration_partners: MutableSequence[
            CampaignThirdPartyViewabilityIntegrationPartner
        ] = ...,
        brand_lift_integration_partners: MutableSequence[
            CampaignThirdPartyBrandLiftIntegrationPartner
        ] = ...,
        brand_safety_integration_partners: MutableSequence[
            CampaignThirdPartyBrandSafetyIntegrationPartner
        ] = ...,
        reach_integration_partners: MutableSequence[
            CampaignThirdPartyReachIntegrationPartner
        ] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "viewability_integration_partners",
            "brand_lift_integration_partners",
            "brand_safety_integration_partners",
            "reach_integration_partners",
        ],
    ) -> bool: ...

class CampaignThirdPartyReachIntegrationPartner(proto.Message):
    reach_integration_partner: (
        ThirdPartyReachIntegrationPartnerEnum.ThirdPartyReachIntegrationPartner
    )
    reach_integration_partner_data: ThirdPartyIntegrationPartnerData
    share_cost: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        reach_integration_partner: ThirdPartyReachIntegrationPartnerEnum.ThirdPartyReachIntegrationPartner = ...,
        reach_integration_partner_data: ThirdPartyIntegrationPartnerData = ...,
        share_cost: bool = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "reach_integration_partner", "reach_integration_partner_data", "share_cost"
        ],
    ) -> bool: ...

class CampaignThirdPartyViewabilityIntegrationPartner(proto.Message):
    viewability_integration_partner: ThirdPartyViewabilityIntegrationPartnerEnum.ThirdPartyViewabilityIntegrationPartner
    viewability_integration_partner_data: ThirdPartyIntegrationPartnerData
    share_cost: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        viewability_integration_partner: ThirdPartyViewabilityIntegrationPartnerEnum.ThirdPartyViewabilityIntegrationPartner = ...,
        viewability_integration_partner_data: ThirdPartyIntegrationPartnerData = ...,
        share_cost: bool = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "viewability_integration_partner",
            "viewability_integration_partner_data",
            "share_cost",
        ],
    ) -> bool: ...

class CustomerThirdPartyBrandLiftIntegrationPartner(proto.Message):
    brand_lift_integration_partner: (
        ThirdPartyBrandLiftIntegrationPartnerEnum.ThirdPartyBrandLiftIntegrationPartner
    )
    allow_share_cost: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        brand_lift_integration_partner: ThirdPartyBrandLiftIntegrationPartnerEnum.ThirdPartyBrandLiftIntegrationPartner = ...,
        allow_share_cost: bool = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["brand_lift_integration_partner", "allow_share_cost"]
    ) -> bool: ...

class CustomerThirdPartyBrandSafetyIntegrationPartner(proto.Message):
    brand_safety_integration_partner: ThirdPartyBrandSafetyIntegrationPartnerEnum.ThirdPartyBrandSafetyIntegrationPartner
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        brand_safety_integration_partner: ThirdPartyBrandSafetyIntegrationPartnerEnum.ThirdPartyBrandSafetyIntegrationPartner = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["brand_safety_integration_partner"]
    ) -> bool: ...

class CustomerThirdPartyIntegrationPartners(proto.Message):
    viewability_integration_partners: MutableSequence[
        CustomerThirdPartyViewabilityIntegrationPartner
    ]
    brand_lift_integration_partners: MutableSequence[
        CustomerThirdPartyBrandLiftIntegrationPartner
    ]
    brand_safety_integration_partners: MutableSequence[
        CustomerThirdPartyBrandSafetyIntegrationPartner
    ]
    reach_integration_partners: MutableSequence[
        CustomerThirdPartyReachIntegrationPartner
    ]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        viewability_integration_partners: MutableSequence[
            CustomerThirdPartyViewabilityIntegrationPartner
        ] = ...,
        brand_lift_integration_partners: MutableSequence[
            CustomerThirdPartyBrandLiftIntegrationPartner
        ] = ...,
        brand_safety_integration_partners: MutableSequence[
            CustomerThirdPartyBrandSafetyIntegrationPartner
        ] = ...,
        reach_integration_partners: MutableSequence[
            CustomerThirdPartyReachIntegrationPartner
        ] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "viewability_integration_partners",
            "brand_lift_integration_partners",
            "brand_safety_integration_partners",
            "reach_integration_partners",
        ],
    ) -> bool: ...

class CustomerThirdPartyReachIntegrationPartner(proto.Message):
    reach_integration_partner: (
        ThirdPartyReachIntegrationPartnerEnum.ThirdPartyReachIntegrationPartner
    )
    allow_share_cost: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        reach_integration_partner: ThirdPartyReachIntegrationPartnerEnum.ThirdPartyReachIntegrationPartner = ...,
        allow_share_cost: bool = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["reach_integration_partner", "allow_share_cost"]
    ) -> bool: ...

class CustomerThirdPartyViewabilityIntegrationPartner(proto.Message):
    viewability_integration_partner: ThirdPartyViewabilityIntegrationPartnerEnum.ThirdPartyViewabilityIntegrationPartner
    allow_share_cost: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        viewability_integration_partner: ThirdPartyViewabilityIntegrationPartnerEnum.ThirdPartyViewabilityIntegrationPartner = ...,
        allow_share_cost: bool = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["viewability_integration_partner", "allow_share_cost"]
    ) -> bool: ...

class ThirdPartyIntegrationPartnerData(proto.Message):
    client_id: str
    third_party_placement_id: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        client_id: str = ...,
        third_party_placement_id: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["client_id", "third_party_placement_id"]
    ) -> bool: ...



from .async_client import (
    AssetGenerationServiceAsyncClient as AssetGenerationServiceAsyncClient,
)
from .client import AssetGenerationServiceClient as AssetGenerationServiceClient

__all__ = ["AssetGenerationServiceClient", "AssetGenerationServiceAsyncClient"]



from .async_client import (
    KeywordPlanCampaignKeywordServiceAsyncClient as KeywordPlanCampaignKeywordServiceAsyncClient,
)
from .client import (
    KeywordPlanCampaignKeywordServiceClient as KeywordPlanCampaignKeywordServiceClient,
)

__all__ = [
    "KeywordPlanCampaignKeywordServiceClient",
    "KeywordPlanCampaignKeywordServiceAsyncClient",
]



from .async_client import (
    ConversionAdjustmentUploadServiceAsyncClient as ConversionAdjustmentUploadServiceAsyncClient,
)
from .client import (
    ConversionAdjustmentUploadServiceClient as ConversionAdjustmentUploadServiceClient,
)

__all__ = [
    "ConversionAdjustmentUploadServiceClient",
    "ConversionAdjustmentUploadServiceAsyncClient",
]



from .base import KeywordPlanIdeaServiceTransport as KeywordPlanIdeaServiceTransport
from .grpc import (
    KeywordPlanIdeaServiceGrpcTransport as KeywordPlanIdeaServiceGrpcTransport,
)
from .grpc_asyncio import (
    KeywordPlanIdeaServiceGrpcAsyncIOTransport as KeywordPlanIdeaServiceGrpcAsyncIOTransport,
)

__all__ = [
    "KeywordPlanIdeaServiceTransport",
    "KeywordPlanIdeaServiceGrpcTransport",
    "KeywordPlanIdeaServiceGrpcAsyncIOTransport",
]



from .async_client import ReachPlanServiceAsyncClient as ReachPlanServiceAsyncClient
from .client import ReachPlanServiceClient as ReachPlanServiceClient

__all__ = ["ReachPlanServiceClient", "ReachPlanServiceAsyncClient"]



from .base import AdGroupAdServiceTransport as AdGroupAdServiceTransport
from .grpc import AdGroupAdServiceGrpcTransport as AdGroupAdServiceGrpcTransport
from .grpc_asyncio import (
    AdGroupAdServiceGrpcAsyncIOTransport as AdGroupAdServiceGrpcAsyncIOTransport,
)

__all__ = [
    "AdGroupAdServiceTransport",
    "AdGroupAdServiceGrpcTransport",
    "AdGroupAdServiceGrpcAsyncIOTransport",
]



from .base import (
    AdGroupBidModifierServiceTransport as AdGroupBidModifierServiceTransport,
)
from .grpc import (
    AdGroupBidModifierServiceGrpcTransport as AdGroupBidModifierServiceGrpcTransport,
)
from .grpc_asyncio import (
    AdGroupBidModifierServiceGrpcAsyncIOTransport as AdGroupBidModifierServiceGrpcAsyncIOTransport,
)

__all__ = [
    "AdGroupBidModifierServiceTransport",
    "AdGroupBidModifierServiceGrpcTransport",
    "AdGroupBidModifierServiceGrpcAsyncIOTransport",
]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from google.protobuf.field_mask_pb2 import FieldMask
from google.rpc.status_pb2 import Status
from typing_extensions import Literal

from google.ads.googleads.v22.enums.types.response_content_type import (
    ResponseContentTypeEnum,
)
from google.ads.googleads.v22.resources.types.campaign import Campaign

_M = TypeVar("_M")

class BrandCampaignAssets(proto.Message):
    business_name_asset: str
    logo_asset: MutableSequence[str]
    landscape_logo_asset: MutableSequence[str]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        business_name_asset: str = ...,
        logo_asset: MutableSequence[str] = ...,
        landscape_logo_asset: MutableSequence[str] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["business_name_asset", "logo_asset", "landscape_logo_asset"]
    ) -> bool: ...

class CampaignOperation(proto.Message):
    update_mask: FieldMask
    create: Campaign
    update: Campaign
    remove: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        update_mask: FieldMask = ...,
        create: Campaign = ...,
        update: Campaign = ...,
        remove: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["update_mask", "create", "update", "remove"]
    ) -> bool: ...

class EnableOperation(proto.Message):
    campaign: str
    auto_populate_brand_assets: bool
    brand_assets: BrandCampaignAssets
    final_uri_domain: str
    main_color: str
    accent_color: str
    font_family: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        campaign: str = ...,
        auto_populate_brand_assets: bool = ...,
        brand_assets: BrandCampaignAssets = ...,
        final_uri_domain: str = ...,
        main_color: str = ...,
        accent_color: str = ...,
        font_family: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "campaign",
            "auto_populate_brand_assets",
            "brand_assets",
            "final_uri_domain",
            "main_color",
            "accent_color",
            "font_family",
        ],
    ) -> bool: ...

class EnablePMaxBrandGuidelinesRequest(proto.Message):
    customer_id: str
    operations: MutableSequence[EnableOperation]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        operations: MutableSequence[EnableOperation] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["customer_id", "operations"]
    ) -> bool: ...

class EnablePMaxBrandGuidelinesResponse(proto.Message):
    results: MutableSequence[EnablementResult]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        results: MutableSequence[EnablementResult] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["results"]
    ) -> bool: ...

class EnablementResult(proto.Message):
    campaign: str
    enablement_error: Status
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        campaign: str = ...,
        enablement_error: Status = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["campaign", "enablement_error"]
    ) -> bool: ...

class MutateCampaignResult(proto.Message):
    resource_name: str
    campaign: Campaign
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        campaign: Campaign = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["resource_name", "campaign"]
    ) -> bool: ...

class MutateCampaignsRequest(proto.Message):
    customer_id: str
    operations: MutableSequence[CampaignOperation]
    partial_failure: bool
    validate_only: bool
    response_content_type: ResponseContentTypeEnum.ResponseContentType
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        operations: MutableSequence[CampaignOperation] = ...,
        partial_failure: bool = ...,
        validate_only: bool = ...,
        response_content_type: ResponseContentTypeEnum.ResponseContentType = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "customer_id",
            "operations",
            "partial_failure",
            "validate_only",
            "response_content_type",
        ],
    ) -> bool: ...

class MutateCampaignsResponse(proto.Message):
    partial_failure_error: Status
    results: MutableSequence[MutateCampaignResult]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        partial_failure_error: Status = ...,
        results: MutableSequence[MutateCampaignResult] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["partial_failure_error", "results"]
    ) -> bool: ...



from .base import LocalServicesLeadServiceTransport as LocalServicesLeadServiceTransport
from .grpc import (
    LocalServicesLeadServiceGrpcTransport as LocalServicesLeadServiceGrpcTransport,
)
from .grpc_asyncio import (
    LocalServicesLeadServiceGrpcAsyncIOTransport as LocalServicesLeadServiceGrpcAsyncIOTransport,
)

__all__ = [
    "LocalServicesLeadServiceTransport",
    "LocalServicesLeadServiceGrpcTransport",
    "LocalServicesLeadServiceGrpcAsyncIOTransport",
]



from .base import CustomAudienceServiceTransport as CustomAudienceServiceTransport
from .grpc import (
    CustomAudienceServiceGrpcTransport as CustomAudienceServiceGrpcTransport,
)
from .grpc_asyncio import (
    CustomAudienceServiceGrpcAsyncIOTransport as CustomAudienceServiceGrpcAsyncIOTransport,
)

__all__ = [
    "CustomAudienceServiceTransport",
    "CustomAudienceServiceGrpcTransport",
    "CustomAudienceServiceGrpcAsyncIOTransport",
]



from .async_client import (
    CampaignDraftServiceAsyncClient as CampaignDraftServiceAsyncClient,
)
from .client import CampaignDraftServiceClient as CampaignDraftServiceClient

__all__ = ["CampaignDraftServiceClient", "CampaignDraftServiceAsyncClient"]



from .async_client import ExperimentServiceAsyncClient as ExperimentServiceAsyncClient
from .client import ExperimentServiceClient as ExperimentServiceClient

__all__ = ["ExperimentServiceClient", "ExperimentServiceAsyncClient"]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from google.rpc.status_pb2 import Status
from typing_extensions import Literal

from google.ads.googleads.v22.enums.types.response_content_type import (
    ResponseContentTypeEnum,
)
from google.ads.googleads.v22.resources.types.campaign_asset_set import CampaignAssetSet

_M = TypeVar("_M")

class CampaignAssetSetOperation(proto.Message):
    create: CampaignAssetSet
    remove: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        create: CampaignAssetSet = ...,
        remove: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["create", "remove"]
    ) -> bool: ...

class MutateCampaignAssetSetResult(proto.Message):
    resource_name: str
    campaign_asset_set: CampaignAssetSet
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        campaign_asset_set: CampaignAssetSet = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["resource_name", "campaign_asset_set"]
    ) -> bool: ...

class MutateCampaignAssetSetsRequest(proto.Message):
    customer_id: str
    operations: MutableSequence[CampaignAssetSetOperation]
    partial_failure: bool
    validate_only: bool
    response_content_type: ResponseContentTypeEnum.ResponseContentType
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        operations: MutableSequence[CampaignAssetSetOperation] = ...,
        partial_failure: bool = ...,
        validate_only: bool = ...,
        response_content_type: ResponseContentTypeEnum.ResponseContentType = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "customer_id",
            "operations",
            "partial_failure",
            "validate_only",
            "response_content_type",
        ],
    ) -> bool: ...

class MutateCampaignAssetSetsResponse(proto.Message):
    results: MutableSequence[MutateCampaignAssetSetResult]
    partial_failure_error: Status
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        results: MutableSequence[MutateCampaignAssetSetResult] = ...,
        partial_failure_error: Status = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["results", "partial_failure_error"]
    ) -> bool: ...



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from google.rpc.status_pb2 import Status
from typing_extensions import Literal

from google.ads.googleads.v22.resources.types.user_list_customer_type import (
    UserListCustomerType,
)

_M = TypeVar("_M")

class MutateUserListCustomerTypeResult(proto.Message):
    resource_name: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["resource_name"]
    ) -> bool: ...

class MutateUserListCustomerTypesRequest(proto.Message):
    customer_id: str
    operations: MutableSequence[UserListCustomerTypeOperation]
    partial_failure: bool
    validate_only: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        operations: MutableSequence[UserListCustomerTypeOperation] = ...,
        partial_failure: bool = ...,
        validate_only: bool = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal["customer_id", "operations", "partial_failure", "validate_only"],
    ) -> bool: ...

class MutateUserListCustomerTypesResponse(proto.Message):
    partial_failure_error: Status
    results: MutableSequence[MutateUserListCustomerTypeResult]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        partial_failure_error: Status = ...,
        results: MutableSequence[MutateUserListCustomerTypeResult] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["partial_failure_error", "results"]
    ) -> bool: ...

class UserListCustomerTypeOperation(proto.Message):
    create: UserListCustomerType
    remove: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        create: UserListCustomerType = ...,
        remove: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["create", "remove"]
    ) -> bool: ...



from .async_client import (
    CampaignConversionGoalServiceAsyncClient as CampaignConversionGoalServiceAsyncClient,
)
from .client import (
    CampaignConversionGoalServiceClient as CampaignConversionGoalServiceClient,
)

__all__ = [
    "CampaignConversionGoalServiceClient",
    "CampaignConversionGoalServiceAsyncClient",
]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

_M = TypeVar("_M")

class AdGroupCriterionPrimaryStatusReasonEnum(proto.Message):
    class AdGroupCriterionPrimaryStatusReason(proto.Enum):
        UNSPECIFIED = 0
        UNKNOWN = 1
        CAMPAIGN_PENDING = 2
        CAMPAIGN_CRITERION_NEGATIVE = 3
        CAMPAIGN_PAUSED = 4
        CAMPAIGN_REMOVED = 5
        CAMPAIGN_ENDED = 6
        AD_GROUP_PAUSED = 7
        AD_GROUP_REMOVED = 8
        AD_GROUP_CRITERION_DISAPPROVED = 9
        AD_GROUP_CRITERION_RARELY_SERVED = 10
        AD_GROUP_CRITERION_LOW_QUALITY = 11
        AD_GROUP_CRITERION_UNDER_REVIEW = 12
        AD_GROUP_CRITERION_PENDING_REVIEW = 13
        AD_GROUP_CRITERION_BELOW_FIRST_PAGE_BID = 14
        AD_GROUP_CRITERION_NEGATIVE = 15
        AD_GROUP_CRITERION_RESTRICTED = 16
        AD_GROUP_CRITERION_PAUSED = 17
        AD_GROUP_CRITERION_PAUSED_DUE_TO_LOW_ACTIVITY = 18
        AD_GROUP_CRITERION_REMOVED = 19

    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: NoReturn
    ) -> bool: ...



from .async_client import (
    CustomInterestServiceAsyncClient as CustomInterestServiceAsyncClient,
)
from .client import CustomInterestServiceClient as CustomInterestServiceClient

__all__ = ["CustomInterestServiceClient", "CustomInterestServiceAsyncClient"]
